@@ -20,20 +20,25 @@
 
 #include "config.h"
 
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <guile/gh.h>
 #include <ctype.h>
 #include <locale.h>
 #include <string.h>
 
-#include <glib.h>
-#include <guile/gh.h>
-
+#include "gfec.h"
 #include "finproto.h"
 #include "fin_spl_protos.h"
-#include "global-options.h"
+#include "gnc-filepath-utils.h"
+#include "gnc-gkeyfile-utils.h"
 #include "gnc-exp-parser.h"
-#include "messages.h"
 #include "gnc-ui-util.h"
+#include "guile-mappings.h"
 
+#define GROUP_NAME "Variables"
+
+static QofLogModule log_module = GNC_MOD_GUI;
 
 /** Data Types *****************************************************/
 
@@ -52,6 +57,12 @@ static gboolean      parser_inited     = FALSE;
 
 /** Implementations ************************************************/
 
+static gchar *
+gnc_exp_parser_filname (void)
+{
+  return gnc_build_dotgnucash_path("expressions-2.0");
+}
+
 void
 gnc_exp_parser_init ( void )
 {
@@ -61,7 +72,9 @@ gnc_exp_parser_init ( void )
 void
 gnc_exp_parser_real_init ( gboolean addPredefined )
 {
-  SCM alist;
+  gchar *filename, **keys, **key, *str_value;
+  GKeyFile *key_file;
+  gnc_numeric value;
 
   if (parser_inited)
     gnc_exp_parser_shutdown ();
@@ -72,59 +85,20 @@ gnc_exp_parser_real_init ( gboolean addPredefined )
   parser_inited = TRUE;
 
   if ( addPredefined ) {
-    alist = gnc_lookup_option ("__exp_parser", "defined_variables", SCM_EOL);
-
-    while (gh_list_p(alist) && !gh_null_p(alist))
-      {
-        char *name;
-        SCM assoc;
-        SCM val_scm;
-        gnc_numeric value;
-        gboolean good;
-
-        assoc = gh_car (alist);
-        alist = gh_cdr (alist);
-
-        if (!gh_pair_p (assoc))
-          continue;
-
-        name = gh_scm2newstr (gh_car (assoc), NULL);
-        if (name == NULL)
-          continue;
-
-        val_scm = gh_cdr (assoc);
-        good = TRUE;
-
-        if (gh_number_p (val_scm))
-          {
-            double dvalue;
-
-            dvalue = gh_scm2double (val_scm);
-            value = double_to_gnc_numeric (dvalue, GNC_DENOM_AUTO, 
-                                           GNC_DENOM_SIGFIGS(6)
-                                           | GNC_RND_ROUND);
-          }
-        else if (gh_string_p (val_scm))
-          {
-            char *s;
-            gboolean err;
-
-            s = gh_scm2newstr (val_scm, NULL);
-
-            err = string_to_gnc_numeric (s, &value);
-            if (err == FALSE)
-              good = FALSE;
-
-            free (s);
-          }
-        else
-          good = FALSE;
-
-        if (good)
-          gnc_exp_parser_set_value (name, gnc_numeric_reduce (value));
-
-        free (name);
-      }
+    filename = gnc_exp_parser_filname();
+    key_file = gnc_key_file_load_from_file(filename, TRUE, FALSE);
+    if (key_file) {
+      keys = g_key_file_get_keys(key_file, GROUP_NAME, NULL, NULL);
+      for (key = keys; key && *key; key++) {
+	str_value = g_key_file_get_string(key_file, GROUP_NAME, *key, NULL);
+	if (str_value && string_to_gnc_numeric(str_value, &value)) {
+	  gnc_exp_parser_set_value (*key, gnc_numeric_reduce (value));
+	}
+      } 
+      g_strfreev(keys);
+      g_key_file_free(key_file);
+    }
+    g_free(filename);
   }
 }
 
@@ -138,32 +112,35 @@ remove_binding (gpointer key, gpointer value, gpointer not_used)
 }
 
 static void
-binding_cons (gpointer key, gpointer value, gpointer data)
+set_one_key (gpointer key, gpointer value, gpointer data)
 {
   char *name = key;
   ParserNum *pnum = value;
-  SCM *alist_p = data;
   char *num_str;
-  SCM assoc;
 
   num_str = gnc_numeric_to_string (gnc_numeric_reduce (pnum->value));
-  assoc = gh_cons (gh_str02scm (name), gh_str02scm (num_str));
+  g_key_file_set_string ((GKeyFile *)data, GROUP_NAME, name, num_str);
   g_free (num_str);
-
-  *alist_p = gh_cons (assoc, *alist_p);
 }
 
 void
 gnc_exp_parser_shutdown (void)
 {
-  SCM alist;
+  GKeyFile* key_file;
+  gchar *filename;
 
   if (!parser_inited)
     return;
 
-  alist = SCM_EOL;
-  g_hash_table_foreach (variable_bindings, binding_cons, &alist);
-  gnc_set_option ("__exp_parser", "defined_variables", alist);
+  filename = gnc_exp_parser_filname();
+  key_file = g_key_file_new();
+  g_hash_table_foreach (variable_bindings, set_one_key, key_file);
+  g_key_file_set_comment(key_file, GROUP_NAME, NULL,
+			 _(" Variables are in the form 'name=value'"),
+			 NULL);
+  gnc_key_file_save_to_file(filename, key_file, NULL);
+  g_key_file_free(key_file);
+  g_free(filename);
 
   g_hash_table_foreach_remove (variable_bindings, remove_binding, NULL);
   g_hash_table_destroy (variable_bindings);
@@ -345,10 +322,16 @@ update_variables (var_store_ptr vars)
   }
 }
 
+static char* _function_evaluation_error_msg = NULL;
+static void
+_exception_handler(const char *error_message)
+{
+  _function_evaluation_error_msg = (char*)error_message;
+}
+
 static
 void*
-func_op( const char *fname,
-         int argc, void **argv )
+func_op(const char *fname, int argc, void **argv)
 {
   SCM scmFn, scmArgs, scmTmp;
   int i;
@@ -358,26 +341,26 @@ func_op( const char *fname,
   GString *realFnName;
 
   realFnName = g_string_sized_new( strlen(fname) + 5 );
-  g_string_sprintf( realFnName, "gnc:%s", fname );
+  g_string_printf( realFnName, "gnc:%s", fname );
   scmFn = gh_eval_str_with_standard_handler( realFnName->str );
   g_string_free( realFnName, TRUE );
-  if ( ! gh_procedure_p( scmFn ) ) {
+  if (!SCM_PROCEDUREP(scmFn)) {
     /* FIXME: handle errors correctly. */
     printf( "gnc:\"%s\" is not a scm procedure\n", fname );
     return NULL;
   }
-  scmArgs = gh_list( SCM_UNDEFINED );
+  scmArgs = scm_listify( SCM_UNDEFINED );
   for ( i=0; i<argc; i++ ) {
     /* cons together back-to-front. */
     vs = (var_store*)argv[argc - i - 1];
     switch ( vs->type ) {
     case VST_NUMERIC:
       n = *(gnc_numeric*)(vs->value);
-      scmTmp = gh_double2scm( gnc_numeric_to_double( n ) );
+      scmTmp = scm_make_real( gnc_numeric_to_double( n ) );
       break;
     case VST_STRING:
       str = (char*)(vs->value);
-      scmTmp = gh_str2scm( str, strlen(str) );
+      scmTmp = scm_mem2string( str, strlen(str) );
       break;
     default:
       /* FIXME: error */
@@ -386,22 +369,30 @@ func_op( const char *fname,
       return NULL;
       break; /* notreached */
     }
-    scmArgs = gh_cons( scmTmp, scmArgs );
+    scmArgs = scm_cons( scmTmp, scmArgs );
   }
-  scmTmp = gh_apply( scmFn, scmArgs );
-  
+
+  //scmTmp = scm_apply(scmFn, scmArgs , SCM_EOL);
+  scmTmp = gfec_apply(scmFn, scmArgs, _exception_handler);
+  if (_function_evaluation_error_msg != NULL)
+  {
+    PERR("function eval error: [%s]\n", _function_evaluation_error_msg);
+    _function_evaluation_error_msg = NULL;
+    return NULL;
+  }
+    
   result = g_new0( gnc_numeric, 1 );
-  *result = double_to_gnc_numeric( gh_scm2double(scmTmp),
+  *result = double_to_gnc_numeric( scm_num2dbl(scmTmp, __FUNCTION__),
                                    GNC_DENOM_AUTO,
                                    GNC_DENOM_SIGFIGS(6) | GNC_RND_ROUND );
-  /* FIXME: cleanup scmArgs = gh_list, cons'ed cells? */
+  /* FIXME: cleanup scmArgs = scm_list, cons'ed cells? */
   return (void*)result;
 }
 
 static void *
 trans_numeric(const char *digit_str,
-              char        radix_point,
-              char        group_char,
+              gchar      *radix_point,
+              gchar      *group_char,
               char      **rstr)
 {
   ParserNum *pnum;
@@ -478,8 +469,6 @@ gnc_ep_tmpvarhash_check_vals( gpointer key, gpointer value, gpointer user_data )
 {
   gboolean *allVarsHaveValues = (gboolean*)user_data;
   gnc_numeric *num = (gnc_numeric*)value;
-  printf( "var %s with value %s\n",
-          (char*)key, num ? gnc_numeric_to_string( *num ) : "(null)" );
   *allVarsHaveValues &= ( num && gnc_numeric_check( *num ) != GNC_ERROR_ARG );
 }
 
@@ -557,7 +546,7 @@ gnc_exp_parser_parse_separate_vars (const char * expression,
 
   lc = gnc_localeconv ();
 
-  pe = init_parser (vars, *lc->mon_decimal_point, *lc->mon_thousands_sep,
+  pe = init_parser (vars, lc->mon_decimal_point, lc->mon_thousands_sep,
                     trans_numeric, numeric_ops, negate_numeric, g_free,
                     func_op);
 
