@@ -16,12 +16,14 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
-/** @addtogroup UI
+/** @addtogroup GUI
     @{ */
+/** @addtogroup GuiUtility Utility functions for the GnuCash GUI
+ * @{ */
 /** @file gnc-ui-util.h 
     @brief  utility functions for the GnuCash UI
     @author Copyright (C) 2000 Dave Peticolas <dave@krondo.com>
@@ -30,88 +32,78 @@
 #ifndef GNC_UI_UTIL_H
 #define GNC_UI_UTIL_H
 
-#include "config.h"
-
 #include <glib.h>
 #include <locale.h>
 
 #include "Account.h"
-#include "gnc-engine.h"
 #include "Group.h"
-#include "gnc-session.h"
+#include "qof.h"
 
 
-typedef GNCSession * (*GNCSessionCB) (void);
+typedef QofSession * (*QofSessionCB) (void);
 
 
-/* User Settings ****************************************************/
-gboolean gnc_color_deficits (void);
-
-char gnc_get_account_separator (void);
-
-gboolean gnc_reverse_balance(Account *account);
+gboolean gnc_reverse_balance(const Account *account);
 gboolean gnc_reverse_balance_type(GNCAccountType type);
 
 
 /* Default directories **********************************************/
 
 void gnc_init_default_directory (char **dirname);
+/** 
+ * Extracts the directory part of the given 'filename' into the char
+ * pointer variable '*dirname'. If the 'filename' is NULL or does not
+ * contain any directory separator '/', then '*dirname' will be set to
+ * NULL.
+ * 
+ * WATCH OUT: If '*dirname' (i.e. the underlying char pointer
+ * variable) is non-NULL, then it will be free()'d. Make sure that you
+ * have initialized it to NULL, or otherwise you will get a bogus
+ * free() or a double-free() here. FIXME: This is probably not-so-good
+ * behaviour and should be changed (2005-10-08, cstim).
+ *
+ * Again watch out: The caller takes ownership of the char buffer
+ * '*dirname', i.e. the caller has to do a g_free(*dirname) when that
+ * buffer is no longer in use.
+ *
+ * NOTE: We strongly recommend to use g_path_get_dirname() from glib
+ * instead of this function. (There's one slight functional difference:
+ * If filename is NULL or does not contain a separator,
+ * g_path_get_dirname will return "." whereas this function here will
+ * return NULL. 2006-03-02, cstim)
+*/
 void gnc_extract_directory (char **dirname, const char *filename);
 
 
 /* Engine enhancements & i18n ***************************************/
-GNCBook * gnc_get_current_book (void);
+QofBook * gnc_get_current_book (void);
 AccountGroup * gnc_get_current_group (void);
 gnc_commodity_table * gnc_get_current_commodities (void);
 
 /*
- * These values are order according to the way they should appear in
- * the register.  If you change this enum, you must also change the
- * acct_tree_defaults data structure in gnc-account-tree.c.
- */
-typedef enum
-{
-  ACCOUNT_NAME = 0,
-  ACCOUNT_TYPE,
-  ACCOUNT_COMMODITY,
-  ACCOUNT_CODE,
-  ACCOUNT_DESCRIPTION,
-  ACCOUNT_PRESENT,
-  ACCOUNT_PRESENT_REPORT,
-  ACCOUNT_BALANCE,        /* with sign reversal */
-  ACCOUNT_BALANCE_REPORT, /* ACCOUNT_BALANCE in default report currency */
-  ACCOUNT_CLEARED,
-  ACCOUNT_CLEARED_REPORT,
-  ACCOUNT_RECONCILED,
-  ACCOUNT_RECONCILED_REPORT,
-  ACCOUNT_FUTURE_MIN,
-  ACCOUNT_FUTURE_MIN_REPORT,
-  ACCOUNT_TOTAL,          /* balance + children's balance with sign reversal */
-  ACCOUNT_TOTAL_REPORT,   /* ACCOUNT_TOTAL in default report currency */
-  ACCOUNT_NOTES,
-  ACCOUNT_TAX_INFO,
-  NUM_ACCOUNT_FIELDS
-} AccountFieldCode;
-
-/**
- * This routine retrives the content for any given field in the
- * account tree data structure.  The account specifies the "row" and
- * the field parameter specifies the "column".  In essence, this is
- * one giant accessor routine for the Account object where all the
- * results are string values.
+ * This is a wrapper routine around an xaccGetBalanceInCurrency
+ * function that handles additional needs of the gui.
  *
- * @param account  The account to retrieve data about.
- * @param field    An indicator of which field in the account tree to return
- * @param negative An indicator that the result was a negative numeric
- *                 value.  May be used by the caller for colorization of the
- *                 returned string.
- * @return         The textual string representing the requested field.
- *
- * @note The caller must free the returned string when done with it.
+ * @param fn        The underlying function in Account.c to call to retrieve
+ *                  a specific balance from the account.
+ * @param account   The account to retrieve data about.
+ * @param recurse   Include all sub-accounts of this account.
+ * @param negative  An indication of whether or not the returned value
+ *                  is negative.  This can be used by the caller to
+ *                  easily decode whether or not to color the output.
+ * @param commodity The commodity in which the account balance should
+ *                  be returned. If NULL, the value will be returned in
+ *                  the commodity of the account. This is normally used
+ *                  to specify a currency, which forces the conversion
+ *                  of things like stock account values from share
+ *                  values to an amount the requested currency.
  */
-char * gnc_ui_account_get_field_value_string (Account *account,
-                                              AccountFieldCode field,
-					      gboolean *negative);
+gnc_numeric
+gnc_ui_account_get_balance_full (xaccGetBalanceInCurrencyFn fn,
+				 const Account *account,
+				 gboolean recurse,
+				 gboolean *negative,
+				 const gnc_commodity *commodity);
 
 /**
  * This routine retrives the total balance in an account, possibly
@@ -120,11 +112,11 @@ char * gnc_ui_account_get_field_value_string (Account *account,
  * @param account           The account to retrieve data about.
  * @param include_children  Include all sub-accounts of this account.
  */
-gnc_numeric gnc_ui_account_get_balance (Account *account,
+gnc_numeric gnc_ui_account_get_balance (const Account *account,
                                         gboolean include_children);
 
-gnc_numeric gnc_ui_account_get_balance_in_currency (Account *account,
-						    gnc_commodity *currency,
+gnc_numeric gnc_ui_account_get_balance_in_currency (const Account *account,
+						    const gnc_commodity *currency,
 						    gboolean recurse);
 /**
  * This routine retrives the reconciled balance in an account,
@@ -133,9 +125,50 @@ gnc_numeric gnc_ui_account_get_balance_in_currency (Account *account,
  * @param account           The account to retrieve data about.
  * @param include_children  Include all sub-accounts of this account.
  */
-gnc_numeric gnc_ui_account_get_reconciled_balance(Account *account,
+gnc_numeric gnc_ui_account_get_reconciled_balance(const Account *account,
                                                   gboolean include_children);
 
+/**
+ * Wrapper around gnc_ui_account_get_balance_internal that converts
+ * the resulting number to a character string.  The number is
+ * formatted according to the specification of the account currency.
+ *
+ * @param fn        The underlying function in Account.c to call to retrieve
+ *                  a specific balance from the account.
+ * @param account   The account to retrieve data about.
+ * @param recurse   Include all sub-accounts of this account.
+ * @param negative  An indication of whether or not the returned value
+ *                  is negative.  This can be used by the caller to
+ *                  easily decode whether or not to color the output.
+ */
+gchar *
+gnc_ui_account_get_print_balance (xaccGetBalanceInCurrencyFn fn,
+				  const Account *account,
+				  gboolean recurse,
+				  gboolean *negative);
+
+/**
+ * Wrapper around gnc_ui_account_get_balance_internal that converts
+ * the resulting number to a character string.  The number is
+ * formatted according to the specification of the default reporting
+ * currency.
+ *
+ * @param fn        The underlying function in Account.c to call to retrieve
+ *                  a specific balance from the account.
+ * @param account   The account to retrieve data about.
+ * @param recurse   Include all sub-accounts of this account.
+ * @param negative  An indication of whether or not the returned value
+ *                  is negative.  This can be used by the caller to
+ *                  easily decode whether or not to color the output.
+ */
+gchar *
+gnc_ui_account_get_print_report_balance (xaccGetBalanceInCurrencyFn fn,
+					 const Account *account,
+					 gboolean recurse,
+					 gboolean *negative);
+
+char *gnc_ui_account_get_tax_info_string (const Account *account);
+
 gnc_numeric gnc_ui_account_get_balance_as_of_date (Account *account,
                                                    time_t date,
                                                    gboolean include_children);
@@ -154,68 +187,13 @@ typedef enum
 Account * gnc_find_or_create_equity_account (AccountGroup *group,
                                              GNCEquityType equity_type,
                                              gnc_commodity *currency,
-                                             GNCBook *book);
+                                             QofBook *book);
 gboolean gnc_account_create_opening_balance (Account *account,
                                              gnc_numeric balance,
                                              time_t date,
-                                             GNCBook *book);
+                                             QofBook *book);
 
-char * gnc_account_get_full_name (Account *account);
-
-
-/* Price source functions *******************************************/
-
-/* NOTE: If you modify PriceSourceCode, please update price-quotes.scm
-   as well. */
-typedef enum
-{
-  SOURCE_NONE = 0,
-  SPECIFIC_SOURCES,
-  SOURCE_AEX,
-  SOURCE_AMFIINDIA,
-  SOURCE_ASX,
-  SOURCE_DWS,
-  SOURCE_FIDELITY_DIRECT,
-  SOURCE_FOOL,
-  SOURCE_FUNDLIBRARY,
-  SOURCE_TDWATERHOUSE,
-  SOURCE_TDEFUNDS,
-  SOURCE_TIAA_CREF,
-  SOURCE_TROWEPRICE_DIRECT,
-  SOURCE_TRUSTNET,
-  SOURCE_UNION,
-  SOURCE_VANGUARD,
-  SOURCE_VWD,
-  SOURCE_YAHOO,
-  SOURCE_YAHOO_ASIA,
-  SOURCE_YAHOO_AUSTRALIA,
-  SOURCE_YAHOO_EUROPE,
-  SOURCE_ZUERICH,
-  GENERAL_SOURCES,
-  SOURCE_ASIA,
-  SOURCE_AUSTRALIA,
-  SOURCE_CANADA,
-  SOURCE_CANADAMUTUAL,
-  SOURCE_DUTCH,
-  SOURCE_EUROPE,
-  SOURCE_FIDELITY,
-  SOURCE_INDIAMUTUAL,
-  SOURCE_TROWEPRICE,
-  SOURCE_UKUNITTRUSTS,
-  SOURCE_USA,
-  NUM_SOURCES
-} PriceSourceCode;
-/* NOTE: If you modify PriceSourceCode, please update price-quotes.scm
-   as well. */
-
-const char * gnc_price_source_enum2name (PriceSourceCode source);
-const char * gnc_price_source_enum2internal (PriceSourceCode source);
-const char * gnc_price_source_internal2fq (const char * codename);
-PriceSourceCode gnc_price_source_internal2enum (const char * internal_name);
-PriceSourceCode gnc_price_source_fq2enum (const char * fq_name);
-gboolean gnc_price_source_sensitive (PriceSourceCode source);
-void gnc_price_source_set_fq_installed (GList *sources_list);
-gboolean gnc_price_source_have_fq (void);
+char * gnc_account_get_full_name (const Account *account);
 
 
 /* Locale functions *************************************************/
@@ -237,6 +215,25 @@ gnc_commodity * gnc_locale_default_currency (void);
 /* Returns the default ISO currency string of the current locale. */
 const char * gnc_locale_default_iso_currency_code (void);
 
+
+/** Return the default currency set by the user.  If the user's
+ *  preference is invalid, then this routine will return the default
+ *  currency for the user's locale.
+ *
+ *  @return A pointer to a currency.
+ */
+gnc_commodity * gnc_default_currency (void);
+
+
+/** Return the default currency for use in reports, as set by the
+ *  user.  If the user's preference is invalid, then this routine will
+ *  return the default currency for the user's locale.
+ *
+ *  @return A pointer to a currency.
+ */
+gnc_commodity * gnc_default_report_currency (void);
+
+
 /* Returns the number of decimal place to print in the current locale */
 int gnc_locale_decimal_places (void);
 
@@ -282,7 +279,7 @@ GNCPrintAmountInfo gnc_default_print_info (gboolean use_symbol);
 GNCPrintAmountInfo gnc_commodity_print_info (const gnc_commodity *commodity,
                                              gboolean use_symbol);
 
-GNCPrintAmountInfo gnc_account_print_info (Account *account,
+GNCPrintAmountInfo gnc_account_print_info (const Account *account,
                                            gboolean use_symbol);
 
 GNCPrintAmountInfo gnc_split_amount_print_info (Split *split,
@@ -296,6 +293,9 @@ GNCPrintAmountInfo gnc_default_price_print_info (void);
 
 GNCPrintAmountInfo gnc_integral_print_info (void);
 
+/* WARNING: Garbage in, garbage out.  You must check the validity of
+   the supplied gnc_numeric.  If it's invalid, the returned string
+   could point to ANYTHING. */
 const char * xaccPrintAmount (gnc_numeric val, GNCPrintAmountInfo info);
 int xaccSPrintAmount (char *buf, gnc_numeric val, GNCPrintAmountInfo info);
 
@@ -314,15 +314,24 @@ int xaccSPrintAmount (char *buf, gnc_numeric val, GNCPrintAmountInfo info);
 gboolean xaccParseAmount (const char * in_str, gboolean monetary,
                           gnc_numeric *result, char **endstr);
 
+/*
+ * xaccParseAmountExtended is just like xaccParseAmount except the
+ * caller must provide all the locale-specific information.
+ *
+ * Note: if group is NULL, no group-size verification will take place.
+ * ignore_list is a list of characters that are completely ignored
+ * while processing the input string.  If ignore_list is NULL, nothing
+ * is ignored.
+ */
+gboolean
+xaccParseAmountExtended (const char * in_str, gboolean monetary,
+			 gunichar negative_sign, gunichar decimal_point,
+			 gunichar group_separator, char *group, char *ignore_list,
+			 gnc_numeric *result, char **endstr);
 
-/* Automatic decimal place conversion *******************************/
-
-/* enable/disable the auto decimal option */
-void gnc_set_auto_decimal_enabled(gboolean enabled);
-
-/* set how many auto decimal places to use */
-void gnc_set_auto_decimal_places(int places);
+/* Initialization ***************************************************/
 
+void gnc_ui_util_init (void);
 
 /* Missing functions ************************************************/
 
@@ -333,3 +342,4 @@ int iswlower (gint32 wc);
 
 #endif
 /** @} */
+/** @} */
