@@ -16,8 +16,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
  ********************************************************************/
 
@@ -33,10 +33,7 @@
 #include "sixtp-parsers.h"
 #include "sixtp-stack.h"
 
-#include "gnc-engine-util.h"
-
-
-static short module = MOD_IO;
+static QofLogModule log_module = GNC_MOD_IO;
 
 /************************************************************************/
 gboolean
@@ -162,7 +159,7 @@ sixtp_set_any(sixtp *tochange, int cleanup, ...)
     
     if(!tochange)
     {
-        PWARN("Null tochange passed\n");
+        PWARN("Null tochange passed");
         return NULL;
     }
 
@@ -222,7 +219,7 @@ sixtp_set_any(sixtp *tochange, int cleanup, ...)
 
         default:
             va_end(ap);
-            PERR("Bogus sixtp type %d\n", type);
+            PERR("Bogus sixtp type %d", type);
             if(cleanup)
             {
                 sixtp_destroy(tochange);
@@ -262,13 +259,13 @@ sixtp_destroy_child(gpointer key, gpointer value, gpointer user_data)
 
   if(!corpses) 
   {
-    PERR("no corpses in sixtp_destroy_child <%s>\n",
+    PERR("no corpses in sixtp_destroy_child <%s>",
          key ? (char *) key : "(null)");
     return;
   }
   if(!child) 
   {
-    PERR("no child in sixtp_destroy_child <%s>\n",
+    PERR("no child in sixtp_destroy_child <%s>",
          key ? (char *) key : "");
     return;
   }
@@ -339,7 +336,7 @@ sixtp_add_some_sub_parsers(sixtp *tochange, int cleanup, ...)
         handler = va_arg(ap, sixtp*);
         if(!handler)
         {
-            PWARN("Handler for tag %s is null\n",
+            PWARN("Handler for tag %s is null",
                       tag ? tag : "(null)");
 
             if(cleanup)
@@ -431,14 +428,14 @@ sixtp_sax_start_handler(void *user_data,
                                           pdata->global_data,
                                           &(current_frame->frame_data),
                                           current_frame->tag,
-                                          name);
+                                          (gchar*) name);
   }
 
   /* now allocate the new stack frame and shift to it */
-  new_frame = sixtp_stack_frame_new(next_parser, g_strdup(name));
+  new_frame = sixtp_stack_frame_new( next_parser, g_strdup((char*) name));
 
-  new_frame->line = getLineNumber( pdata->saxParserCtxt );
-  new_frame->col  = getColumnNumber( pdata->saxParserCtxt );
+  new_frame->line = xmlSAX2GetLineNumber( pdata->saxParserCtxt );
+  new_frame->col  = xmlSAX2GetColumnNumber( pdata->saxParserCtxt );
   
   pdata->stack = g_slist_prepend(pdata->stack, (gpointer) new_frame);
   
@@ -450,7 +447,7 @@ sixtp_sax_start_handler(void *user_data,
                                  pdata->global_data,
                                  &new_frame->data_for_children,
                                  &new_frame->frame_data,
-                                 name,
+                                 (gchar*) name,
                                  (gchar**)attrs);
   }
 }
@@ -471,7 +468,7 @@ sixtp_sax_characters_handler(void *user_data, const xmlChar *text, int len)
                                         frame->data_for_children,
                                         pdata->global_data,
                                         &result,
-                                        text,
+                                        (gchar*) text,
                                         len);
     if(pdata->parsing_ok && result)
     {
@@ -504,13 +501,13 @@ sixtp_sax_end_handler(void *user_data, const xmlChar *name)
 
   /* time to make sure we got the right closing tag.  Is this really
      necessary? */
-  if(safe_strcmp(current_frame->tag, name) != 0) 
+  if(safe_strcmp(current_frame->tag, (gchar*) name) != 0) 
   {
     PWARN ("bad closing tag (start <%s>, end <%s>)", current_frame->tag, name);
     pdata->parsing_ok = FALSE;
 
     /* See if we're just off by one and try to recover */
-    if(safe_strcmp(parent_frame->tag, name) == 0) {
+    if(safe_strcmp(parent_frame->tag, (gchar*) name) == 0) {
       pdata->stack = sixtp_pop_and_destroy_frame(pdata->stack);
       current_frame = (sixtp_stack_frame *) pdata->stack->data;
       parent_frame = (sixtp_stack_frame *) pdata->stack->next->data;
@@ -594,7 +591,7 @@ sixtp_sax_end_handler(void *user_data, const xmlChar *name)
 }
 
 xmlEntityPtr
-sixtp_sax_get_entity_handler(void *user_data, const CHAR *name) 
+sixtp_sax_get_entity_handler(void *user_data, const xmlChar *name) 
 {
   return xmlGetPredefinedEntity(name);
 }
@@ -614,7 +611,7 @@ sixtp_handle_catastrophe(sixtp_sax_data *sax_data)
   GSList *lp;
   GSList **stack = &(sax_data->stack);
 
-  PERR("parse failed at \n");
+  PERR("parse failed at:");
   sixtp_print_frame_stack(sax_data->stack, stderr);
 
   while(*stack) 
@@ -729,9 +726,11 @@ sixtp_parse_file(sixtp *sixtp,
                  gpointer global_data,
                  gpointer *parse_result) 
 {
-  xmlParserCtxtPtr context = xmlCreateFileParserCtxt( filename );
-  return sixtp_parse_file_common(sixtp, context, data_for_top_level,
-				 global_data, parse_result);
+    gboolean ret;
+    xmlParserCtxtPtr context = xmlCreateFileParserCtxt( filename );
+    ret = sixtp_parse_file_common(sixtp, context, data_for_top_level,
+                                  global_data, parse_result);
+    return ret;
 }
 
 gboolean
@@ -742,14 +741,62 @@ sixtp_parse_buffer(sixtp *sixtp,
                    gpointer global_data,
                    gpointer *parse_result) 
 {
-  xmlParserCtxtPtr context = xmlCreateMemoryParserCtxt( bufp, bufsz );
-  return sixtp_parse_file_common(sixtp, context, data_for_top_level,
-				 global_data, parse_result);
+    gboolean ret;
+    xmlParserCtxtPtr context = xmlCreateMemoryParserCtxt( bufp, bufsz );
+    ret = sixtp_parse_file_common(sixtp, context, data_for_top_level,
+                                  global_data, parse_result);
+    return ret;
+}
+
+gboolean
+sixtp_parse_push (sixtp *sixtp,
+                  sixtp_push_handler push_handler,
+                  gpointer push_user_data,
+                  gpointer data_for_top_level,
+                  gpointer global_data,
+                  gpointer *parse_result)
+{
+    sixtp_parser_context *ctxt;
+    xmlParserCtxtPtr xml_context;
+
+    if (!push_handler) {
+        PERR("No push handler specified");
+        return FALSE;
+    }
+
+    if (!(ctxt = sixtp_context_new(sixtp, global_data, data_for_top_level))) {
+        PERR("sixtp_context_new returned null");
+        return FALSE;
+    }
+
+    xml_context = xmlCreatePushParserCtxt(&ctxt->handler, &ctxt->data,
+                                          NULL, 0, NULL);
+    ctxt->data.saxParserCtxt = xml_context;
+    ctxt->data.bad_xml_parser = sixtp_dom_parser_new(gnc_bad_xml_end_handler,
+                                                     NULL, NULL);
+
+    (*push_handler)(xml_context, push_user_data);
+
+    sixtp_context_run_end_handler(ctxt);
+
+    if (ctxt->data.parsing_ok) {
+        if (parse_result)
+            *parse_result = ctxt->top_frame->frame_data;
+        sixtp_context_destroy(ctxt);
+        return TRUE;
+    } else {
+        if (parse_result)
+            *parse_result = NULL;
+        if (g_slist_length(ctxt->data.stack) > 1)
+            sixtp_handle_catastrophe(&ctxt->data);
+        sixtp_context_destroy(ctxt);
+        return FALSE;
+    }
 }
 
 /***********************************************************************/
 static gboolean
-eat_whitespace(char **cursor)
+eat_whitespace(unsigned char **cursor)
 {
     while(**cursor && isspace(**cursor))
     {
@@ -767,7 +814,7 @@ eat_whitespace(char **cursor)
 }
 
 static gboolean
-search_for(char marker, char **cursor)
+search_for(unsigned char marker, unsigned char **cursor)
 {
     while(**cursor && **cursor != marker)
     {
@@ -786,38 +833,52 @@ search_for(char marker, char **cursor)
 }
 
 gboolean
-gnc_is_our_xml_file(const char *filename, const char *first_tag)
+gnc_is_our_xml_file(const char *filename, const char *first_tag,
+                    gboolean *with_encoding)
 {
   FILE *f = NULL;
   char first_chunk[256];
-  char* cursor = NULL;
   ssize_t num_read;
-  
+
   g_return_val_if_fail(filename, FALSE);
   g_return_val_if_fail(first_tag, FALSE);
-  
+
   f = fopen(filename, "r");
-  if (f == NULL)
+  if (f == NULL) {
     return FALSE;
+  }
 
   num_read = fread(first_chunk, sizeof(char), sizeof(first_chunk) - 1, f);
   fclose(f);
 
-  if(num_read == 0) 
+  if(num_read == 0)
   {
       return FALSE;
   }
-  
+
   first_chunk[num_read] = '\0';
-  
-  cursor = first_chunk;
+
+  return gnc_is_our_first_xml_chunk(first_chunk, first_tag, with_encoding);
+}
+
+gboolean
+gnc_is_our_first_xml_chunk(char *chunk, const char *first_tag,
+                           gboolean *with_encoding)
+{
+  unsigned char* cursor = NULL;
+
+  if (with_encoding) {
+    *with_encoding = FALSE;
+  }
+
+  cursor = chunk;
 
   if(!eat_whitespace(&cursor))
   {
       return FALSE;
   }
-  
-  if(strncmp(cursor, "<?xml", 5) == 0) 
+
+  if(strncmp(cursor, "<?xml", 5) == 0)
   {
       char *tag_compare;
       gboolean result;
@@ -836,6 +897,18 @@ gnc_is_our_xml_file(const char *filename, const char *first_tag)
 
       result = (strncmp(cursor, tag_compare, strlen(tag_compare)) == 0);
       g_free (tag_compare);
+
+      if (result && with_encoding) {
+        *cursor = '\0';
+        cursor = chunk;
+        while (search_for('e', &cursor)) {
+          if (strncmp(cursor, "ncoding=", 8) == 0) {
+            *with_encoding = TRUE;
+            break;
+          }
+        }
+      }
+
       return result;
   }
   else
