@@ -2,21 +2,37 @@
  * dialog-order.c -- Dialog for Order entry
  * Copyright (C) 2001,2002 Derek Atkins
  * Author: Derek Atkins <warlord@MIT.EDU>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, contact:
+ *
+ * Free Software Foundation           Voice:  +1-617-542-5942
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org
  */
 
 #include "config.h"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "dialog-utils.h"
-#include "global-options.h"
 #include "gnc-component-manager.h"
 #include "gnc-ui.h"
 #include "gnc-gui-query.h"
 #include "gnc-ui-util.h"
-#include "gnc-engine-util.h"
+#include "qof.h"
 #include "gnucash-sheet.h"
-#include "window-help.h"
 #include "dialog-search.h"
 #include "search-param.h"
 
@@ -34,6 +50,15 @@
 #define DIALOG_EDIT_ORDER_CM_CLASS "dialog-edit-order"
 #define DIALOG_VIEW_ORDER_CM_CLASS "dialog-view-order"
 
+#define GCONF_SECTION_SEARCH "dialogs/business/order_search"
+
+void gnc_order_window_ok_cb (GtkWidget *widget, gpointer data);
+void gnc_order_window_cancel_cb (GtkWidget *widget, gpointer data);
+void gnc_order_window_help_cb (GtkWidget *widget, gpointer data);
+void gnc_order_window_invoice_cb (GtkWidget *widget, gpointer data);
+void gnc_order_window_close_order_cb (GtkWidget *widget, gpointer data);
+void gnc_order_window_destroy_cb (GtkWidget *widget, gpointer data);
+
 typedef enum
 {
   NEW_ORDER,
@@ -89,6 +114,9 @@ ow_get_order (OrderWindow *ow)
 
 static void gnc_ui_to_order (OrderWindow *ow, GncOrder *order)
 {
+  GtkTextBuffer* text_buffer;
+  GtkTextIter start, end;
+  gchar *text;
   Timespec ts;
   time_t tt;
 
@@ -101,12 +129,16 @@ static void gnc_ui_to_order (OrderWindow *ow, GncOrder *order)
   
   gncOrderSetID (order, gtk_editable_get_chars
 		 (GTK_EDITABLE (ow->id_entry), 0, -1));
-  gncOrderSetNotes (order, gtk_editable_get_chars
-		    (GTK_EDITABLE (ow->notes_text), 0, -1));
+
+  text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(ow->notes_text));
+  gtk_text_buffer_get_bounds (text_buffer, &start, &end);
+  text = gtk_text_buffer_get_text (text_buffer, &start, &end, FALSE);
+  gncOrderSetNotes (order, text);
+
   gncOrderSetReference (order, gtk_editable_get_chars
 			(GTK_EDITABLE (ow->ref_entry), 0, -1));
 
-  tt = gnome_date_edit_get_date (GNOME_DATE_EDIT (ow->opened_date));
+  tt = gnome_date_edit_get_time (GNOME_DATE_EDIT (ow->opened_date));
   timespecFromTime_t (&ts, tt);
   gncOrderSetDateOpened (order, ts);
 
@@ -129,8 +161,8 @@ gnc_order_window_verify_ok (OrderWindow *ow)
   /* Check the ID */
   res = gtk_entry_get_text (GTK_ENTRY (ow->id_entry));
   if (safe_strcmp (res, "") == 0) {
-    gnc_error_dialog_parented (GTK_WINDOW (ow->dialog),
-			       _("The Order must be given an ID."));
+    gnc_error_dialog (ow->dialog,
+		      _("The Order must be given an ID."));
     return FALSE;
   }
 
@@ -138,8 +170,8 @@ gnc_order_window_verify_ok (OrderWindow *ow)
   gnc_owner_get_owner (ow->owner_choice, &(ow->owner));
   res = gncOwnerGetName (&(ow->owner));
   if (res == NULL || safe_strcmp (res, "") == 0) {
-    gnc_error_dialog_parented (GTK_WINDOW (ow->dialog),
-  			       _("You need to supply Billing Information."));
+    gnc_error_dialog (ow->dialog,
+		      _("You need to supply Billing Information."));
     return FALSE;
   }
 
@@ -167,7 +199,7 @@ gnc_order_window_ok_save (OrderWindow *ow)
   return TRUE;
 }
 
-static void
+void
 gnc_order_window_ok_cb (GtkWidget *widget, gpointer data)
 {
   OrderWindow *ow = data;
@@ -181,7 +213,7 @@ gnc_order_window_ok_cb (GtkWidget *widget, gpointer data)
   gnc_close_gui_component (ow->component_id);
 }
 
-static void
+void
 gnc_order_window_cancel_cb (GtkWidget *widget, gpointer data)
 {
   OrderWindow *ow = data;
@@ -189,15 +221,13 @@ gnc_order_window_cancel_cb (GtkWidget *widget, gpointer data)
   gnc_close_gui_component (ow->component_id);
 }
 
-static void
+void
 gnc_order_window_help_cb (GtkWidget *widget, gpointer data)
 {
-  char *help_file = HH_ORDER;
-
-  helpWindow(NULL, NULL, help_file);
+  gnc_gnome_help(HF_HELP, HL_USAGE);
 }
 
-static void
+void
 gnc_order_window_invoice_cb (GtkWidget *widget, gpointer data)
 {
   OrderWindow *ow = data;
@@ -213,7 +243,7 @@ gnc_order_window_invoice_cb (GtkWidget *widget, gpointer data)
   gnc_order_update_window (ow);
 }
 
-static void
+void
 gnc_order_window_close_order_cb (GtkWidget *widget, gpointer data)
 {
   OrderWindow *ow = data;
@@ -234,8 +264,8 @@ gnc_order_window_close_order_cb (GtkWidget *widget, gpointer data)
 
   /* Check that there is at least one Entry */
   if (gncOrderGetEntries (order) == NULL) {
-    gnc_error_dialog_parented (GTK_WINDOW (ow->dialog),
-			       _("The Order must have at least one Entry."));
+    gnc_error_dialog (ow->dialog,
+		      _("The Order must have at least one Entry."));
     return;
   }
 
@@ -254,11 +284,11 @@ gnc_order_window_close_order_cb (GtkWidget *widget, gpointer data)
      * close this order!
      */
 
-    message = _("This order contains entries that have not been invoiced.\n"
-		"Are you sure you want to close it out before\n"
+    message = _("This order contains entries that have not been invoiced. "
+		"Are you sure you want to close it out before "
 		"you invoice all the entries?");
 
-    if (gnc_verify_dialog_parented (ow->dialog, FALSE, message) == FALSE)
+    if (gnc_verify_dialog (ow->dialog, FALSE, message) == FALSE)
       return;
   }
 
@@ -283,7 +313,7 @@ gnc_order_window_close_order_cb (GtkWidget *widget, gpointer data)
   gnc_order_update_window (ow);
 }
 
-static void
+void
 gnc_order_window_destroy_cb (GtkWidget *widget, gpointer data)
 {
   OrderWindow *ow = data;
@@ -347,7 +377,7 @@ gnc_order_window_close_handler (gpointer user_data)
 {
   OrderWindow *ow = user_data;
 
-  gnome_dialog_close (GNOME_DIALOG (ow->dialog));
+  gtk_widget_destroy (ow->dialog);
 }
 
 static void
@@ -366,46 +396,13 @@ gnc_order_window_refresh_handler (GHashTable *changes, gpointer user_data)
   /* Next, close if this is a destroy event */
   if (changes) {
     info = gnc_gui_get_entity_events (changes, &ow->order_guid);
-    if (info && (info->event_mask & GNC_EVENT_DESTROY)) {
+    if (info && (info->event_mask & QOF_EVENT_DESTROY)) {
       gnc_close_gui_component (ow->component_id);
       return;
     }
   }
 }
 
-static void
-gnc_configure_register_colors (void)
-{
-  GncEntryLedgerColors reg_colors;
-
-  reg_colors.header_bg_color =
-    gnc_lookup_color_option_argb("Register Colors",
-                                 "Header color",
-                                 0xffffff);
-
-  reg_colors.primary_bg_color =
-    gnc_lookup_color_option_argb("Register Colors",
-                                 "Primary color",
-                                 0xffffff);
-
-  reg_colors.secondary_bg_color =
-    gnc_lookup_color_option_argb("Register Colors",
-                                 "Secondary color",
-                                 0xffffff);
-
-  reg_colors.primary_active_bg_color =
-    gnc_lookup_color_option_argb("Register Colors",
-                                 "Primary active color",
-                                 0xffffff);
-
-  reg_colors.secondary_active_bg_color =
-    gnc_lookup_color_option_argb("Register Colors",
-                                 "Secondary active color",
-                                 0xffffff);
-
-  gnc_entry_ledger_set_colors (reg_colors);
-}
-
 static void
 gnc_order_update_window (OrderWindow *ow)
 {
@@ -435,25 +432,24 @@ gnc_order_update_window (OrderWindow *ow)
       break;
     }
 
-  gtk_signal_connect (GTK_OBJECT (ow->owner_choice), "changed",
-		      GTK_SIGNAL_FUNC (gnc_order_owner_changed_cb),
-		      ow);
+  g_signal_connect (ow->owner_choice, "changed",
+		    G_CALLBACK (gnc_order_owner_changed_cb),
+		    ow);
 
   gtk_widget_show_all (ow->dialog);
 
   {
+    GtkTextBuffer* text_buffer;
     const char *string;
     Timespec ts, ts_zero = {0,0};
     time_t tt;
-    gint pos = 0;
 
     gtk_entry_set_text (GTK_ENTRY (ow->ref_entry),
 			gncOrderGetReference (order));
 
     string = gncOrderGetNotes (order);
-    gtk_editable_delete_text (GTK_EDITABLE (ow->notes_text), 0, -1);
-    gtk_editable_insert_text (GTK_EDITABLE (ow->notes_text), string,
-			      strlen (string), &pos);
+    text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(ow->notes_text));
+    gtk_text_buffer_set_text (text_buffer, string, -1);
 
     ts = gncOrderGetDateOpened (order);
     if (timespec_equal (&ts, &ts_zero)) {
@@ -484,7 +480,7 @@ gnc_order_update_window (OrderWindow *ow)
 
   gnc_gui_component_watch_entity_type (ow->component_id,
 				       GNC_ORDER_MODULE_NAME,
-				       GNC_EVENT_MODIFY | GNC_EVENT_DESTROY);
+				       QOF_EVENT_MODIFY | QOF_EVENT_DESTROY);
 
   gnc_table_refresh_gui (gnc_entry_ledger_get_table (ow->ledger), TRUE);
 
@@ -533,7 +529,6 @@ gnc_order_new_window (GNCBook *bookp, OrderDialogType type,
   GladeXML *xml;
   GtkWidget *vbox, *regWidget;
   GncEntryLedger *entry_ledger = NULL;
-  GnomeDialog *owd;
   const char * class_name;
 
   switch (type) {
@@ -565,8 +560,6 @@ gnc_order_new_window (GNCBook *bookp, OrderDialogType type,
   /*
    * No existing order window found.  Build a new one.
    */
-  gnc_configure_register_colors ();
-
   ow = g_new0 (OrderWindow, 1);
   ow->book = bookp;
   ow->dialog_type = type;
@@ -577,9 +570,6 @@ gnc_order_new_window (GNCBook *bookp, OrderDialogType type,
   /* Find the dialog */
   ow->xml = xml = gnc_glade_xml_new ("order.glade", "Order Entry Dialog");
   ow->dialog = glade_xml_get_widget (xml, "Order Entry Dialog");
-  owd = GNOME_DIALOG (ow->dialog);
-
-  gtk_object_set_data (GTK_OBJECT (ow->dialog), "dialog_info", ow);
 
   /* Grab the widgets */
   ow->id_entry = glade_xml_get_widget (xml, "id_entry");
@@ -591,10 +581,6 @@ gnc_order_new_window (GNCBook *bookp, OrderDialogType type,
   ow->owner_box = glade_xml_get_widget (xml, "owner_hbox");
   ow->owner_label = glade_xml_get_widget (xml, "owner_label");
 
-  /* default to ok */
-  gnome_dialog_editable_enters (owd, GTK_EDITABLE (ow->id_entry));
-  gnome_dialog_set_default (owd, 0);
-
   /* Build the ledger */
   switch (type) {
   case EDIT_ORDER:
@@ -628,20 +614,10 @@ gnc_order_new_window (GNCBook *bookp, OrderDialogType type,
   // gtk_box_pack_start (GTK_BOX(vbox), toolbar, FALSE, FALSE, 2);
   gtk_box_pack_start (GTK_BOX(vbox), regWidget, TRUE, TRUE, 2);
 
-  gtk_signal_connect (GTK_OBJECT (ow->dialog), "destroy",
-		      GTK_SIGNAL_FUNC(gnc_order_window_destroy_cb), ow);
-
-  gnome_dialog_button_connect (owd, 0,
-			       GTK_SIGNAL_FUNC(gnc_order_window_ok_cb), ow);
-  gnome_dialog_button_connect (owd, 1,
-			       GTK_SIGNAL_FUNC(gnc_order_window_help_cb), ow);
-
-  gnome_dialog_button_connect
-    (owd, 2, GTK_SIGNAL_FUNC(gnc_order_window_invoice_cb), ow);
-
-  gnome_dialog_button_connect
-    (owd, 3, GTK_SIGNAL_FUNC(gnc_order_window_close_order_cb), ow);
-
+  /* Setup signals */
+  glade_xml_signal_autoconnect_full( xml,
+                                     gnc_glade_autoconnect_full_func,
+                                     ow);
   /* Setup initial values */
   ow->order_guid = *gncOrderGetGUID (order);
 
@@ -669,8 +645,8 @@ gnc_order_window_new_order (GNCBook *bookp, GncOwner *owner)
 {
   OrderWindow *ow;
   GladeXML *xml;
-  GnomeDialog *owd;
   GncOrder *order;
+  gchar *string;
 
   ow = g_new0 (OrderWindow, 1);
   ow->book = bookp;
@@ -685,9 +661,8 @@ gnc_order_window_new_order (GNCBook *bookp, GncOwner *owner)
   /* Find the dialog */
   xml = gnc_glade_xml_new ("order.glade", "New Order Dialog");
   ow->dialog = glade_xml_get_widget (xml, "New Order Dialog");
-  owd = GNOME_DIALOG (ow->dialog);
 
-  gtk_object_set_data (GTK_OBJECT (ow->dialog), "dialog_info", ow);
+  g_object_set_data (G_OBJECT (ow->dialog), "dialog_info", ow);
 
   /* Grab the widgets */
   ow->id_entry = glade_xml_get_widget (xml, "id_entry");
@@ -697,24 +672,16 @@ gnc_order_window_new_order (GNCBook *bookp, GncOwner *owner)
   ow->owner_box = glade_xml_get_widget (xml, "owner_hbox");
   ow->owner_label = glade_xml_get_widget (xml, "owner_label");
 
-  /* default to ok */
-  gnome_dialog_editable_enters (owd, GTK_EDITABLE (ow->id_entry));
-  gnome_dialog_set_default (owd, 0);
-
-  gtk_signal_connect (GTK_OBJECT (ow->dialog), "destroy",
-		      GTK_SIGNAL_FUNC(gnc_order_window_destroy_cb), ow);
-
-  gnome_dialog_button_connect (owd, 0,
-			       GTK_SIGNAL_FUNC(gnc_order_window_ok_cb), ow);
-  gnome_dialog_button_connect (owd, 1,
-			       GTK_SIGNAL_FUNC(gnc_order_window_cancel_cb), ow);
-  gnome_dialog_button_connect (owd, 2,
-			       GTK_SIGNAL_FUNC(gnc_order_window_help_cb), ow);
-
+  /* Setup signals */
+  glade_xml_signal_autoconnect_full( xml,
+                                     gnc_glade_autoconnect_full_func,
+                                     ow);
   /* Setup initial values */
   ow->order_guid = *gncOrderGetGUID (order);
-  gtk_entry_set_text (GTK_ENTRY (ow->id_entry),
-		      g_strdup_printf ("%.6lld", gncOrderNextID(bookp)));
+  string = g_strdup_printf ("%.6" G_GINT64_FORMAT,
+			    gncOrderNextID(bookp));
+  gtk_entry_set_text (GTK_ENTRY (ow->id_entry), string);
+  g_free(string);
       
   ow->component_id =
     gnc_register_gui_component (DIALOG_NEW_ORDER_CM_CLASS,
@@ -914,9 +881,11 @@ gnc_order_search (GncOrder *start, GncOwner *owner, GNCBook *book)
   sw->book = book;
   sw->q = q;
 
-  return gnc_search_dialog_create (type, params, columns, q, q2,
+  return gnc_search_dialog_create (type, _("Find Order"),
+				   params, columns, q, q2,
 				   buttons, NULL, new_order_cb,
-				   sw, free_order_cb);
+				   sw, free_order_cb, GCONF_SECTION_SEARCH,
+				   NULL);
 }
 
 GNCSearchWindow *
