@@ -65,10 +65,10 @@ enum {
 static guint signals[LAST_SIGNAL] = { 0 };
 #endif
 
-guint
+GType
 gnc_search_owner_get_type (void)
 {
-  static guint type = 0;
+  static GType type = 0;
 	
   if (!type) {
     GTypeInfo type_info = {
