@@ -17,8 +17,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 
 #ifndef GNUCASH_QUERY_H
@@ -27,15 +27,8 @@
 #include <sys/types.h>
 #include <time.h>
 #include <glib.h>
-
-#include "date.h" 
-#include "gnc-engine.h" 
-#include "GNCId.h" 
-#include "guid.h" 
-#include "kvp_frame.h" 
-
-#include "QueryNew.h"
-#include "QueryCore.h"
+#include "qof.h"
+#include "Account.h"
 
 /*
  * This function defines a compatibility API from the old Query API to
@@ -44,34 +37,31 @@
  * others do not.
  */
 
-typedef QueryNew Query;
+typedef QofQuery Query;
 
-#define xaccMallocQuery()	gncQueryCreateFor(GNC_ID_SPLIT)
-#define xaccFreeQuery		gncQueryDestroy
-#define xaccQueryCopy		gncQueryCopy
-#define xaccQuerySetBook	gncQuerySetBook
+#define xaccMallocQuery()	qof_query_create_for(GNC_ID_SPLIT)
+#define xaccFreeQuery		qof_query_destroy
+#define xaccQueryCopy		qof_query_copy
+#define xaccQuerySetBook	qof_query_set_book
 
-#define xaccQueryInvert		gncQueryInvert
-#define xaccQueryMerge		gncQueryMerge
-#define xaccQueryClear		gncQueryClear
+#define xaccQueryInvert		qof_query_invert
+#define xaccQueryMerge		qof_query_merge
+#define xaccQueryClear		qof_query_clear
 
 /* The xaccQueryHasTerms() routine returns the number of 'OR' terms in the query.
  * The xaccQueryNumTerms() routine returns the total number of terms in the query.
  */
 
-// void xaccQueryPurgeTerms(Query * q, pd_type_t type);
-// gboolean      xaccQueryHasTermType(Query * q, pd_type_t type);
-#define xaccQueryHasTerms	gncQueryHasTerms
-#define xaccQueryNumTerms	gncQueryNumTerms
-// #define xaccQueryGetTerms	gncQueryGetTerms
+#define xaccQueryHasTerms	qof_query_has_terms
+#define xaccQueryNumTerms	qof_query_num_terms
 
 
-#define xaccQuerySetSortIncreasing	gncQuerySetSortIncreasing
+#define xaccQuerySetSortIncreasing	qof_query_set_sort_increasing
 
-#define xaccQuerySetMaxSplits	gncQuerySetMaxResults
-#define xaccQueryGetMaxSplits	gncQueryGetMaxResults
+#define xaccQuerySetMaxSplits	qof_query_set_max_results
+#define xaccQueryGetMaxSplits	qof_query_get_max_results
 
-#define xaccQueryEqual		gncQueryEqual
+#define xaccQueryEqual		qof_query_equal
 
 typedef enum {
   QUERY_TXN_MATCH_ALL=1,   /* match all accounts */
@@ -79,6 +69,8 @@ typedef enum {
 } query_txn_match_t;
 
 /* After the query has been set up, call one of these to run the query. 
+ *    XXX The routines below should be replaced by a query
+ *    that explicitly asks for a list of the desired item.
  *
  * The xaccQueryGetSplits() routine returns all splits matching the 
  *    query.  Any given split will appear at most once in the result;
@@ -114,7 +106,7 @@ typedef enum {
  *    matching accounts, whereas 'AND' acts as a boolean-AND
  *    for matching accounts.  Whew. Got that?
  */
-#define xaccQueryGetSplits	gncQueryRun
+#define xaccQueryGetSplits	qof_query_run
 SplitList   * xaccQueryGetSplitsUniqueTrans(Query *q);
 TransList   * xaccQueryGetTransactions(Query * q, query_txn_match_t type);
 LotList     * xaccQueryGetLots(Query * q, query_txn_match_t type);
@@ -124,15 +116,15 @@ LotList     * xaccQueryGetLots(Query * q, query_txn_match_t type);
  *******************************************************************/
 
 void xaccQueryAddAccountMatch(Query *, AccountList *,
-                              guid_match_t how, QueryOp op);
+                              QofGuidMatch how, QofQueryOp op);
 
 void xaccQueryAddAccountGUIDMatch(Query *, AccountGUIDList *,
-                                  guid_match_t, QueryOp);
+                                  QofGuidMatch, QofQueryOp);
 
-void xaccQueryAddSingleAccountMatch(Query *, Account *, QueryOp);
+void xaccQueryAddSingleAccountMatch(Query *, Account *, QofQueryOp);
 
 void xaccQueryAddStringMatch (Query* q, const char *matchstring,
-			      int case_sens, int use_regexp, QueryOp op,
+			      int case_sens, int use_regexp, QofQueryOp op,
 			      const char * path, ...);
 
 #define xaccQueryAddDescriptionMatch(q,m,c,r,o) \
@@ -149,27 +141,27 @@ void xaccQueryAddStringMatch (Query* q, const char *matchstring,
 				NULL)
 
 void xaccQueryAddNumericMatch (Query *q, gnc_numeric amount,
-			       numeric_match_t sign, query_compare_t how,
-			       QueryOp op, const char * path, ...);
+			       QofNumericMatch sign, QofQueryCompare how,
+			       QofQueryOp op, const char * path, ...);
 
 #define xaccQueryAddValueMatch(q,amt,sgn,how,op) \
 	xaccQueryAddNumericMatch ((q), (amt), (sgn), (how), (op), \
 				SPLIT_VALUE, NULL)
 
 #define xaccQueryAddSharePriceMatch(q,amt,how,op) \
-	xaccQueryAddNumericMatch ((q), (amt), NUMERIC_MATCH_ANY, (how), (op), \
+	xaccQueryAddNumericMatch ((q), (amt), QOF_NUMERIC_MATCH_ANY, (how), (op), \
 				SPLIT_SHARE_PRICE, NULL)
  
 #define xaccQueryAddSharesMatch(q,amt,how,op) \
-	xaccQueryAddNumericMatch ((q), (amt), NUMERIC_MATCH_ANY, (how), (op), \
+	xaccQueryAddNumericMatch ((q), (amt), QOF_NUMERIC_MATCH_ANY, (how), (op), \
 				SPLIT_AMOUNT, NULL)
 
 #define xaccQueryAddBalanceMatch(q,bal,op) \
-	xaccQueryAddNumericMatch ((q), gnc_numeric_zero(), NUMERIC_MATCH_ANY, \
-				((bal) ? COMPARE_EQUAL : COMPARE_NEQ), (op), \
+	xaccQueryAddNumericMatch ((q), gnc_numeric_zero(), QOF_NUMERIC_MATCH_ANY, \
+				((bal) ? QOF_COMPARE_EQUAL : QOF_COMPARE_NEQ), (op), \
 				SPLIT_TRANS, TRANS_IMBALANCE, NULL)
 
-/* The DateMatch queries match transactions whose posted date
+/** The DateMatch queries match transactions whose posted date
  *    is in a date range.  If use_start is TRUE, then a matching
  *    posted date will be greater than the start date.   If 
  *    use_end is TRUE, then a match occurs for posted dates earlier 
@@ -181,15 +173,22 @@ void xaccQueryAddNumericMatch (Query *q, gnc_numeric amount,
 void xaccQueryAddDateMatch(Query * q, 
                            int use_start, int sday, int smonth, int syear, 
                            int use_end, int eday, int emonth, int eyear,
-                           QueryOp op);
+                           QofQueryOp op);
 void xaccQueryAddDateMatchTS(Query * q, 
                              int use_start, Timespec sts, 
                              int use_end, Timespec ets,
-                             QueryOp op);
+                             QofQueryOp op);
 void xaccQueryAddDateMatchTT(Query * q, 
                              int use_start, time_t stt, 
                              int use_end, time_t ett,
-                             QueryOp op);
+                             QofQueryOp op);
+void xaccQueryGetDateMatchTS (Query * q, 
+			      Timespec * sts,
+			      Timespec * ets);
+void xaccQueryGetDateMatchTT (Query * q, 
+			      time_t * stt,
+			      time_t * ett);
+
 typedef enum {
   CLEARED_NONE       = 0x0000,
   CLEARED_NO         = 0x0001,
@@ -200,18 +199,16 @@ typedef enum {
   CLEARED_ALL        = 0x001F
 } cleared_match_t;
 
-void xaccQueryAddClearedMatch(Query * q, cleared_match_t how, QueryOp op);
+void xaccQueryAddClearedMatch(Query * q, cleared_match_t how, QofQueryOp op);
 void xaccQueryAddGUIDMatch(Query * q, const GUID *guid,
-                           GNCIdType id_type, QueryOp op);
-void xaccQueryAddGUIDMatchGL (QueryNew *q, GList *param_list,
-			      GUID guid, QueryOp op);
+                           QofIdType id_type, QofQueryOp op);
+void xaccQueryAddGUIDMatchGL (QofQuery *q, GList *param_list,
+			      GUID guid, QofQueryOp op);
 
-/* given kvp value is on right side of comparison */
-void xaccQueryAddKVPMatch(Query *q, GSList *path, const kvp_value *value,
-                          query_compare_t how, GNCIdType id_type,
-                          QueryOp op);
-
-void xaccQuerySetSortOrder(Query *q, GList *p1, GList *p2, GList *p3);
+/** given kvp value is on right side of comparison */
+void xaccQueryAddKVPMatch(Query *q, GSList *path, const KvpValue *value,
+                          QofQueryCompare how, QofIdType id_type,
+                          QofQueryOp op);
 
 /*******************************************************************
  *  compatibility interface with old Query API 
