@@ -84,11 +84,12 @@ struct gnc_new_iso_code
   const char *old_code;
   const char *new_code;
 } gnc_new_iso_codes[] = {
-  {"RUB", "RUR"}, /* Russian Ruble */
+  {"RUR", "RUB"}, /* Russian Ruble: RUR through 1997-12, RUB from 1998-01 onwards; see bug #393185 */
   {"PLZ", "PLN"}, /* Polish Zloty */
   {"UAG", "UAH"}, /* Ukraine Hryvnia */
   {"ILS", "NIS"}, /* New Israeli Shekel */
   {"MXP", "MXN"}, /* Mexican (Nuevo) Peso */
+  {"TRL", "TRY"}, /* New Turkish Lira: changed 2005 */
 
   /* Only add currencies to this table when the old currency no longer
    * exists in the file iso-4217-currencies.scm */
@@ -476,12 +477,12 @@ gnc_commodity_begin_edit (gnc_commodity *cm)
   qof_begin_edit(&cm->inst);
 }
 
-static inline void commit_err (QofInstance *inst, QofBackendError errcode)
+static void commit_err (QofInstance *inst, QofBackendError errcode)
 {
   PERR ("Failed to commit: %d", errcode);
 }
 
-static inline void noop (QofInstance *inst) {}
+static void noop (QofInstance *inst) {}
 
 void
 gnc_commodity_commit_edit (gnc_commodity *cm)
