@@ -1,6 +1,6 @@
 
 #include <glib.h>
-#include <guile/gh.h>
+#include <libguile.h>
 
 #include "engine-helpers.h"
 #include "gnc-module.h"
@@ -23,9 +23,11 @@ test_query (Query *q)
   if (!xaccQueryEqual (q, q2))
   {
     failure ("queries don't match");
-    gh_display (scm_q); gh_newline ();
+    scm_display (scm_q, SCM_UNDEFINED);
+    scm_newline (SCM_UNDEFINED);
     scm_q = gnc_query2scm (q2);
-    gh_display (scm_q); gh_newline ();
+    scm_display (scm_q, SCM_UNDEFINED);
+    scm_newline (SCM_UNDEFINED);
     exit (1);
   }
   else
@@ -57,7 +59,7 @@ run_tests (void)
 }
 
 static void
-main_helper (int argc, char **argv)
+main_helper (void *closure, int argc, char **argv)
 {
   gnc_module_load("gnucash/engine", 0);
 
@@ -76,6 +78,6 @@ main_helper (int argc, char **argv)
 int
 main (int argc, char **argv)
 {
-  gh_enter (argc, argv, main_helper);
+  scm_boot_guile (argc, argv, main_helper, NULL);
   return 0;
 }
