@@ -2,21 +2,37 @@
  * dialog-search.c -- Search Dialog
  * Copyright (C) 2002 Derek Atkins
  * Author: Derek Atkins <warlord@MIT.EDU>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, contact:
+ *
+ * Free Software Foundation           Voice:  +1-617-542-5942
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org
  */
 
 #include "config.h"
 
-#include <gnome.h>
-#include <glib.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "dialog-utils.h"
-#include "window-help.h"
 #include "gnc-component-manager.h"
 #include "gnc-ui-util.h"
 #include "gnc-ui.h"
 #include "gnc-gui-query.h"
-#include "global-options.h"
 #include "gnc-query-list.h"
+#include "gnc-gconf-utils.h"
 #include "gncObject.h"
 #include "QueryNew.h"
 #include "QueryObject.h"
@@ -29,6 +45,7 @@
 #include "search-param.h"
 
 #define DIALOG_SEARCH_CM_CLASS "dialog-search"
+#define KEY_ACTIVE_ONLY "search_for_active_only"
 
 typedef enum {
   GNC_SEARCH_MATCH_ALL = 0,
@@ -71,9 +88,10 @@ struct _GNCSearchWindow {
   gboolean		allow_clear;
 
   /* What we're searching for, and how */
+  const gchar *  type_label;
   GNCIdTypeConst search_for;
   GNCSearchType	grouping;	/* Match Any, Match All */
-  QueryAccess	get_guid;	/* Function to GetGUID from the object */
+  const QofParam * get_guid;	/* Function to GetGUID from the object */
   int		search_type;	/* New, Narrow, Add, Delete */
 
   /* Our query status */
@@ -88,6 +106,7 @@ struct _GNCSearchWindow {
   GList *	crit_list;	/* list of crit_data */
 
   gint		component_id;
+  const gchar * gconf_section;
 };
 
 struct _crit_data {
@@ -96,7 +115,7 @@ struct _crit_data {
   GtkWidget *		elemwidget;
   GtkWidget *		container;
   GtkWidget *		button;
-  GnomeDialog *		dialog;
+  GtkDialog *		dialog;
 };
 
 static void search_clear_criteria (GNCSearchWindow *sw);
@@ -115,7 +134,7 @@ gnc_search_dialog_result_clicked (GtkButton *button, GNCSearchWindow *sw)
 {
   GNCSearchCallbackButton *cb;
 
-  cb = gtk_object_get_data (GTK_OBJECT (button), "data");
+  cb = g_object_get_data (G_OBJECT (button), "data");
   gnc_search_callback_button_execute (cb, sw);
 }
 
@@ -126,7 +145,7 @@ gnc_search_dialog_select_cb (GtkButton *button, GNCSearchWindow *sw)
 
   if (sw->selected_item == NULL && sw->allow_clear == FALSE) {
     char *msg = _("You must select an item from the list");
-    gnc_error_dialog_parented (GTK_WINDOW (sw->dialog), msg);
+    gnc_error_dialog (sw->dialog, msg);
     return;
   }
 
@@ -134,6 +153,7 @@ gnc_search_dialog_select_cb (GtkButton *button, GNCSearchWindow *sw)
   gnc_search_dialog_destroy (sw);
 }
 
+#if 0
 static void
 gnc_search_dialog_line_toggled (GNCQueryList *list, gpointer item,
 				gpointer user_data)
@@ -164,6 +184,40 @@ gnc_search_dialog_double_click_entry (GNCQueryList *list, gpointer item,
     /* Call the first button (usually view/edit) */
     gnc_search_callback_button_execute (sw->buttons, sw);
 }
+#endif
+
+static void
+gnc_search_dialog_select_row_cb (GtkCList *clist, gint row, gint column,
+				 GdkEventButton *event, gpointer user_data)
+{
+  GNCSearchWindow *sw = user_data;
+  sw->selected_item = gtk_clist_get_row_data (clist, row);
+
+  /* If we double-click an item, then either "select" it, or run it
+   * through the first button (which should be view/edit
+   */
+  if (event && event->type == GDK_2BUTTON_PRESS) {
+    if (sw->selected_cb)
+      /* Select the time */
+      gnc_search_dialog_select_cb (NULL, sw);
+    else if (sw->buttons)
+      /* Call the first button (usually view/edit) */
+      gnc_search_callback_button_execute (sw->buttons, sw);
+
+    /* If we get here, then nothing to do for a double-click */
+  }
+}
+
+static void
+gnc_search_dialog_unselect_row_cb (GtkCList *clist, gint row, gint column,
+				   GdkEventButton *event, gpointer user_data)
+{
+  GNCSearchWindow *sw = user_data;
+  gpointer item = gtk_clist_get_row_data (clist, row);
+
+  if (sw->selected_item == item)
+    sw->selected_item = NULL;
+}
 
 static void
 gnc_search_dialog_init_result_list (GNCSearchWindow *sw)
@@ -171,10 +225,10 @@ gnc_search_dialog_init_result_list (GNCSearchWindow *sw)
   sw->result_list = gnc_query_list_new(sw->display_list, sw->q);
 
   /* Setup the list callbacks */
-  gtk_signal_connect (GTK_OBJECT (sw->result_list), "line_toggled",
-		      gnc_search_dialog_line_toggled, sw);
-  gtk_signal_connect (GTK_OBJECT (sw->result_list), "double_click_entry",
-		      gnc_search_dialog_double_click_entry, sw);
+  g_signal_connect (G_OBJECT (sw->result_list), "select-row",
+		    G_CALLBACK (gnc_search_dialog_select_row_cb), sw);
+  g_signal_connect (G_OBJECT (sw->result_list), "unselect-row",
+		    G_CALLBACK (gnc_search_dialog_unselect_row_cb), sw);
 }
 
 static void
@@ -197,7 +251,7 @@ gnc_search_dialog_display_results (GNCSearchWindow *sw)
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroller),
 				    GTK_POLICY_AUTOMATIC,
 				    GTK_POLICY_AUTOMATIC);
-    gtk_widget_set_usize(GTK_WIDGET(scroller), 300, 100);
+    gtk_widget_set_size_request(GTK_WIDGET(scroller), 300, 100);
     gtk_container_add (GTK_CONTAINER (scroller), sw->result_list);
 
     /* Create the button_box */
@@ -208,16 +262,16 @@ gnc_search_dialog_display_results (GNCSearchWindow *sw)
       int i;
 
       button = gtk_button_new_with_label (_("Select"));
-      gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			  gnc_search_dialog_select_cb, sw);
+      g_signal_connect (G_OBJECT (button), "clicked",
+			G_CALLBACK (gnc_search_dialog_select_cb), sw);
       gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
       sw->select_button = button;
 			  
       for (i = 0; sw->buttons[i].label; i++) {
-	button = gtk_button_new_with_label (sw->buttons[i].label);
-	gtk_object_set_data (GTK_OBJECT (button), "data", &(sw->buttons[i]));
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			    gnc_search_dialog_result_clicked, sw);
+	button = gtk_button_new_with_label (_(sw->buttons[i].label));
+	g_object_set_data (G_OBJECT (button), "data", &(sw->buttons[i]));
+	g_signal_connect (G_OBJECT (button), "clicked",
+			  G_CALLBACK (gnc_search_dialog_result_clicked), sw);
 	gtk_box_pack_start (GTK_BOX (button_box), button, FALSE, FALSE, 3);
       }
     }
@@ -238,7 +292,7 @@ gnc_search_dialog_display_results (GNCSearchWindow *sw)
   gnc_query_list_reset_query (GNC_QUERY_LIST(sw->result_list), sw->q);
 
   /* set 'new search' if fewer than max_count items is returned. */
-  max_count = gnc_lookup_number_option ("_+Advanced", "New Search Limit", 0.0);
+  max_count = gnc_gconf_get_float("dialogs/search", "new_search_limit", NULL);
   if (gnc_query_list_get_num_entries(GNC_QUERY_LIST(sw->result_list)) < max_count)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (sw->new_rb), TRUE);
 }
@@ -258,7 +312,7 @@ match_any (GtkWidget *widget, GNCSearchWindow *sw)
 static void
 search_type_cb (GtkToggleButton *button, GNCSearchWindow *sw)
 {
-  GSList * buttongroup = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+  GSList * buttongroup = gtk_radio_button_get_group (GTK_RADIO_BUTTON(button));
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button))) {
     sw->search_type =
@@ -269,8 +323,9 @@ search_type_cb (GtkToggleButton *button, GNCSearchWindow *sw)
 static void
 search_active_only_cb (GtkToggleButton *button, GNCSearchWindow *sw)
 {
-  gnc_set_boolean_option("__gui", "search_for_active_only",
-			 gtk_toggle_button_get_active (button));
+
+  gnc_gconf_set_bool(sw->gconf_section, KEY_ACTIVE_ONLY,
+		     gtk_toggle_button_get_active (button), NULL);
 }
 
 static void
@@ -424,14 +479,15 @@ search_new_item_cb (GtkButton *button, GNCSearchWindow *sw)
 
   res = (sw->new_item_cb)(sw->user_data);
 
-  if (res) {
-    const GUID *guid = (const GUID *) ((sw->get_guid)(res));
+  if (res) 
+  {
+    const GUID *guid = (const GUID *) ((sw->get_guid->param_getfcn)(res, sw->get_guid));
     QueryOp op = QUERY_OR;
 
     if (!sw->q) {
       if (!sw->start_q) {
-	sw->start_q = gncQueryCreateFor (sw->search_for);
-	gncQuerySetBook (sw->start_q, gnc_get_current_book ());
+        sw->start_q = gncQueryCreateFor (sw->search_for);
+        gncQuerySetBook (sw->start_q, gnc_get_current_book ());
       }
       sw->q = gncQueryCopy (sw->start_q);
       op = QUERY_AND;
@@ -441,7 +497,7 @@ search_new_item_cb (GtkButton *button, GNCSearchWindow *sw)
 			  guid, op);
 
     /* Watch this entity so we'll refresh once it's actually changed */
-    gnc_gui_component_watch_entity (sw->component_id, guid, GNC_EVENT_MODIFY);
+    gnc_gui_component_watch_entity (sw->component_id, guid, QOF_EVENT_MODIFY);
   }
 }
 
@@ -456,7 +512,7 @@ search_cancel_cb (GtkButton *button, GNCSearchWindow *sw)
 static void
 search_help_cb (GtkButton *button, GNCSearchWindow *sw)
 {
-  helpWindow (NULL, NULL, HH_FIND_TRANSACTIONS);
+  gnc_gnome_help (HF_HELP, HL_FIND_TRANSACTIONS);
 }
 
 static void
@@ -468,8 +524,8 @@ remove_element (GtkWidget *button, GNCSearchWindow *sw)
   if (g_list_length (sw->crit_list) < 2)
     return;
 
-  element = gtk_object_get_data (GTK_OBJECT (button), "element");
-  data = gtk_object_get_data (GTK_OBJECT (element), "data");
+  element = g_object_get_data (G_OBJECT (button), "element");
+  data = g_object_get_data (G_OBJECT (element), "data");
 
   /* remove the element from the list */
   sw->crit_list = g_list_remove (sw->crit_list, data);
@@ -482,18 +538,18 @@ remove_element (GtkWidget *button, GNCSearchWindow *sw)
 static void
 attach_element (GtkWidget *element, GNCSearchWindow *sw, int row)
 {
-  GtkWidget *pixmap, *remove;
+  GtkWidget *remove;
   struct _crit_data *data;
 
-  data = gtk_object_get_data (GTK_OBJECT (element), "data");
+  data = g_object_get_data (G_OBJECT (element), "data");
 
   gtk_table_attach (GTK_TABLE (sw->criteria_table), element, 0, 1, row, row+1,
 		    GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-  pixmap = gnome_stock_new_with_icon (GNOME_STOCK_PIXMAP_REMOVE);
-  remove = gnome_pixmap_button (pixmap, _("Remove"));
-  gtk_object_set_data (GTK_OBJECT (remove), "element", element);
-  gtk_signal_connect (GTK_OBJECT (remove), "clicked", remove_element, sw);
+  
+  remove = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+  g_object_set_data (G_OBJECT (remove), "element", element);
+  g_signal_connect (G_OBJECT (remove), "clicked", G_CALLBACK (remove_element), sw);
   gtk_table_attach (GTK_TABLE (sw->criteria_table), remove, 1, 2, row, row+1,
 		    0, 0, 0, 0);
   gtk_widget_show (remove);
@@ -503,7 +559,7 @@ attach_element (GtkWidget *element, GNCSearchWindow *sw, int row)
 static void
 option_activate (GtkMenuItem *item, struct _crit_data *data)
 {
-  GNCSearchParam *param = gtk_object_get_data (GTK_OBJECT (item), "param");
+  GNCSearchParam *param = g_object_get_data (G_OBJECT (item), "param");
   GNCSearchCoreType *newelem;
 
   if (gnc_search_param_type_match (param, data->param)) {
@@ -519,7 +575,7 @@ option_activate (GtkMenuItem *item, struct _crit_data *data)
    */
   if (data->elemwidget)
     gtk_container_remove (GTK_CONTAINER (data->container), data->elemwidget);
-  gtk_object_destroy (GTK_OBJECT (data->element));
+  g_object_unref (G_OBJECT (data->element));
 
   newelem = gnc_search_core_type_new_type_name
     (gnc_search_param_get_param_type (param));
@@ -538,7 +594,7 @@ option_activate (GtkMenuItem *item, struct _crit_data *data)
 
   /* And grab focus */
   gnc_search_core_type_grab_focus (newelem);
-  gnc_search_core_type_editable_enters (newelem, data->dialog);
+  gnc_search_core_type_editable_enters (newelem);
 }
 
 static void
@@ -549,7 +605,7 @@ search_clear_criteria (GNCSearchWindow *sw)
   for (node = sw->crit_list; node; ) {
     GList *tmp = node->next;
     struct _crit_data *data = node->data;
-    gtk_object_ref (GTK_OBJECT(data->button));
+    g_object_ref (data->button);
     remove_element (data->button, sw);
     node = tmp;
   }
@@ -565,11 +621,11 @@ get_element_widget (GNCSearchWindow *sw, GNCSearchCoreType *element)
 
   data = g_new0 (struct _crit_data, 1);
   data->element = element;
-  data->dialog = GNOME_DIALOG (sw->dialog);
+  data->dialog = GTK_DIALOG (sw->dialog);
 
   hbox = gtk_hbox_new (FALSE, 0);
   /* only set to automaticaly clean up the memory */
-  gtk_object_set_data_full (GTK_OBJECT (hbox), "data", data, g_free);
+  g_object_set_data_full (G_OBJECT (hbox), "data", data, g_free);
 
   p = gnc_search_core_type_get_widget (element);
   data->elemwidget = p;
@@ -580,9 +636,9 @@ get_element_widget (GNCSearchWindow *sw, GNCSearchCoreType *element)
   for (l = sw->params_list; l; l = l->next) {
     GNCSearchParam *param = l->data;
     item = gtk_menu_item_new_with_label (_(param->title));
-    gtk_object_set_data (GTK_OBJECT (item), "param", param);
-    gtk_signal_connect (GTK_OBJECT (item), "activate", option_activate, data);
-    gtk_menu_append (GTK_MENU (menu), item);
+    g_object_set_data (G_OBJECT (item), "param", param);
+    g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (option_activate), data);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
     gtk_widget_show (item);
 
     if (param == sw->last_param) /* is this the right parameter to start? */
@@ -627,7 +683,7 @@ gnc_search_dialog_add_criterion (GNCSearchWindow *sw)
     int rows;
 
     w = get_element_widget (sw, new);
-    data = gtk_object_get_data (GTK_OBJECT (w), "data");
+    data = g_object_get_data (G_OBJECT (w), "data");
     sw->crit_list = g_list_append (sw->crit_list, data);
 
     rows = GTK_TABLE (sw->criteria_table)->nrows;
@@ -635,7 +691,7 @@ gnc_search_dialog_add_criterion (GNCSearchWindow *sw)
     attach_element (w, sw, rows);
 
     gnc_search_core_type_grab_focus (new);
-    gnc_search_core_type_editable_enters (new, GNOME_DIALOG (sw->dialog));
+    gnc_search_core_type_editable_enters (new);
   }
 }
 
@@ -646,7 +702,7 @@ add_criterion (GtkWidget *button, GNCSearchWindow *sw)
 }
 
 static int
-gnc_search_dialog_close_cb (GnomeDialog *dialog, GNCSearchWindow *sw)
+gnc_search_dialog_close_cb (GtkDialog *dialog, GNCSearchWindow *sw)
 {
   g_return_val_if_fail (sw, TRUE);
 
@@ -683,23 +739,26 @@ close_handler (gpointer data)
   GNCSearchWindow * sw = data;
 
   g_return_if_fail (sw);
-  gnome_dialog_close (GNOME_DIALOG (sw->dialog));
+  gtk_widget_destroy (sw->dialog);
+  /* DRH: should sw be freed here? */
 }
 
 static void
-gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
+gnc_search_dialog_init_widgets (GNCSearchWindow *sw, const gchar *title)
 {
   GladeXML *xml;
-  GtkWidget *label, *pixmap, *add, *box;
+  GtkWidget *label, *add, *box;
   GtkWidget *menu, *item, *omenu;
   GtkWidget *new_item_button;
   const char * type_label;
+  gboolean active;
 
   xml = gnc_glade_xml_new ("search.glade", "Search Dialog");
 
   /* Grab the dialog, save the dialog info */
   sw->dialog = glade_xml_get_widget (xml, "Search Dialog");
-  gtk_object_set_data (GTK_OBJECT (sw->dialog), "dialog-info", sw);
+  gtk_window_set_title(GTK_WINDOW(sw->dialog), title);
+  g_object_set_data (G_OBJECT (sw->dialog), "dialog-info", sw);
 
   /* grab the result hbox */
   sw->result_hbox = glade_xml_get_widget (xml, "result_hbox");
@@ -709,13 +768,16 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
 
   /* Set the type label */
   label = glade_xml_get_widget (xml, "type_label");
-  type_label = gncObjectGetTypeLabel (sw->search_for);
+  if (sw->type_label)
+    type_label = sw->type_label;
+  else
+    type_label = _(gncObjectGetTypeLabel (sw->search_for));
   gtk_label_set_text (GTK_LABEL (label), type_label);
 
   /* Set the 'add criterion' button */
-  pixmap = gnome_stock_new_with_icon (GNOME_STOCK_PIXMAP_ADD);
-  add = gnome_pixmap_button (pixmap, _("Add criterion"));
-  gtk_signal_connect (GTK_OBJECT (add), "clicked", add_criterion, sw);
+  add = gtk_button_new_from_stock (GTK_STOCK_ADD);
+ 
+  g_signal_connect (G_OBJECT (add), "clicked", G_CALLBACK (add_criterion), sw);
   box = glade_xml_get_widget (xml, "add_button_box");
   gtk_box_pack_start (GTK_BOX (box), add, FALSE, FALSE, 3);
   
@@ -723,13 +785,13 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
   menu = gtk_menu_new ();
 
   item = gtk_menu_item_new_with_label (_("all criteria are met"));
-  gtk_signal_connect (GTK_OBJECT (item), "activate", match_all, sw);
-  gtk_menu_append (GTK_MENU (menu), item);
+  g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (match_all), sw);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 	
   item = gtk_menu_item_new_with_label (_("any criteria are met"));
-  gtk_signal_connect (GTK_OBJECT (item), "activate", match_any, sw);
-  gtk_menu_append (GTK_MENU (menu), item);
+  g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (match_any), sw);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 	
   omenu = gtk_option_menu_new ();
@@ -747,11 +809,10 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
   sw->add_rb = glade_xml_get_widget (xml, "add_search_radiobutton");
   sw->del_rb = glade_xml_get_widget (xml, "delete_search_radiobutton");
 
+  active = gnc_gconf_get_bool(sw->gconf_section, KEY_ACTIVE_ONLY, NULL);
   sw->active_only_check = glade_xml_get_widget (xml, "active_only_check");
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sw->active_only_check),
-				gnc_lookup_boolean_option ("__gui",
-							   "search_for_active_only",
-							   TRUE));
+				active);
 
   /* Figure out if we this object-type has an "active" parameter, and
    * if not, then set the active-check button insensitive
@@ -770,7 +831,7 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
       /* Translators: %s is either "item" or the name of some other
        * item, e.g. "Customer" or "Invoice". */
       g_strdup_printf (_("New %s"), type_label ? type_label : _("item"));
-    gtk_label_set_text (GTK_LABEL (GTK_BIN (new_item_button)->child), desc);
+    gtk_button_set_label (GTK_BUTTON(new_item_button), desc);
     g_free (desc);
   }
   /* add the first criterion */
@@ -786,25 +847,25 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
   /* Connect XML signals */
 
   glade_xml_signal_connect_data (xml, "gnc_ui_search_type_cb",
-				 GTK_SIGNAL_FUNC (search_type_cb), sw);
+				 G_CALLBACK (search_type_cb), sw);
   
   glade_xml_signal_connect_data (xml, "gnc_ui_search_active_cb",
-				 GTK_SIGNAL_FUNC (search_active_only_cb), sw);
+				 G_CALLBACK (search_active_only_cb), sw);
 
   glade_xml_signal_connect_data (xml, "gnc_ui_search_new_cb",
-				 GTK_SIGNAL_FUNC (search_new_item_cb), sw);
+				 G_CALLBACK (search_new_item_cb), sw);
   
   glade_xml_signal_connect_data (xml, "gnc_ui_search_find_cb",
-				 GTK_SIGNAL_FUNC (search_find_cb), sw);
+				 G_CALLBACK (search_find_cb), sw);
   
   glade_xml_signal_connect_data (xml, "gnc_ui_search_cancel_cb",
-				 GTK_SIGNAL_FUNC (search_cancel_cb), sw);
+				 G_CALLBACK (search_cancel_cb), sw);
 
   glade_xml_signal_connect_data (xml, "gnc_ui_search_close_cb",
-				 GTK_SIGNAL_FUNC (search_cancel_cb), sw);
+				 G_CALLBACK (search_cancel_cb), sw);
   
   glade_xml_signal_connect_data (xml, "gnc_ui_search_help_cb",
-				 GTK_SIGNAL_FUNC (search_help_cb), sw);
+				 G_CALLBACK (search_help_cb), sw);
 
   /* Register ourselves */
   sw->component_id = gnc_register_gui_component (DIALOG_SEARCH_CM_CLASS,
@@ -812,8 +873,8 @@ gnc_search_dialog_init_widgets (GNCSearchWindow *sw)
 						 close_handler, sw);
 
   /* And setup the close callback */
-  gtk_signal_connect (GTK_OBJECT (sw->dialog), "close",
-		      GTK_SIGNAL_FUNC (gnc_search_dialog_close_cb), sw);
+  g_signal_connect (G_OBJECT (sw->dialog), "destroy",
+		    G_CALLBACK (gnc_search_dialog_close_cb), sw);
 
   gnc_search_dialog_reset_widgets (sw);
   gnc_search_dialog_show_close_cancel (sw);
@@ -823,6 +884,8 @@ void
 gnc_search_dialog_destroy (GNCSearchWindow *sw)
 {
   if (!sw) return;
+  if (sw->gconf_section)
+    gnc_save_window_size(sw->gconf_section, GTK_WINDOW(sw->dialog));
   gnc_close_gui_component (sw->component_id);
 }
 
@@ -834,13 +897,16 @@ gnc_search_dialog_raise (GNCSearchWindow *sw)
 }
 
 GNCSearchWindow *
-gnc_search_dialog_create (GNCIdTypeConst obj_type, GList *param_list,
+gnc_search_dialog_create (GNCIdTypeConst obj_type, const gchar *title,
+			  GList *param_list,
 			  GList *display_list,
 			  QueryNew *start_query, QueryNew *show_start_query,
 			  GNCSearchCallbackButton *callbacks,
 			  GNCSearchResultCB result_callback,
 			  GNCSearchNewItemCB new_item_cb,
-			  gpointer user_data, GNCSearchFree free_cb)
+			  gpointer user_data, GNCSearchFree free_cb,
+			  const gchar *gconf_section,
+			  const gchar *type_label)
 {
   GNCSearchWindow *sw = g_new0 (GNCSearchWindow, 1);
 
@@ -863,15 +929,18 @@ gnc_search_dialog_create (GNCIdTypeConst obj_type, GList *param_list,
   sw->new_item_cb = new_item_cb;
   sw->user_data = user_data;
   sw->free_cb = free_cb;
+  sw->gconf_section = gconf_section;
+  sw->type_label = type_label;
 
   /* Grab the get_guid function */
-  sw->get_guid = gncQueryObjectGetParameterGetter (sw->search_for,
-						   QUERY_PARAM_GUID);
+  sw->get_guid = qof_class_get_parameter (sw->search_for, QOF_PARAM_GUID);
   if (start_query)
     sw->start_q = gncQueryCopy (start_query);
   sw->q = show_start_query;
 
-  gnc_search_dialog_init_widgets (sw);
+  gnc_search_dialog_init_widgets (sw, title);
+  if (sw->gconf_section)
+    gnc_restore_window_size(sw->gconf_section, GTK_WINDOW(sw->dialog));
 
   /* Maybe display the original query results? */
   if (callbacks && show_start_query) {
@@ -884,15 +953,15 @@ gnc_search_dialog_create (GNCIdTypeConst obj_type, GList *param_list,
 
 /* Register an on-close signal with the Search Dialog */
 guint gnc_search_dialog_connect_on_close (GNCSearchWindow *sw,
-					  GtkSignalFunc func,
+					  GCallback func,
 					  gpointer user_data)
 {
   g_return_val_if_fail (sw, 0);
   g_return_val_if_fail (func, 0);
   g_return_val_if_fail (user_data, 0);
 
-  return gtk_signal_connect (GTK_OBJECT (sw->dialog), "close",
-			     func, user_data);
+  return g_signal_connect (G_OBJECT (sw->dialog), "destroy",
+			   func, user_data);
 
 }
 
@@ -902,7 +971,8 @@ void gnc_search_dialog_disconnect (GNCSearchWindow *sw, gpointer user_data)
   g_return_if_fail (sw);
   g_return_if_fail (user_data);
 
-  gtk_signal_disconnect_by_data (GTK_OBJECT (sw->dialog), user_data);  
+  g_signal_handlers_disconnect_matched (sw->dialog, G_SIGNAL_MATCH_DATA,
+					0, 0, NULL, NULL, user_data);  
 }
 
 /* Clear all callbacks with this Search Window */
@@ -1003,6 +1073,8 @@ gnc_search_dialog_test (void)
   if (display == NULL)
     display = get_display_list (GNC_ID_SPLIT);
 
-  sw = gnc_search_dialog_create (GNC_ID_SPLIT, params, display,
-				 NULL, NULL, buttons, NULL, NULL, NULL, NULL);
+  sw = gnc_search_dialog_create (GNC_ID_SPLIT, _("Find Transaction"),
+				 params, display,
+				 NULL, NULL, buttons, NULL, NULL, NULL, NULL,
+				 NULL, NULL);
 }
