@@ -86,8 +86,9 @@ typedef struct _AccountWindow
   GtkWidget * commodity_edit;
   dialog_commodity_mode commodity_mode;
   GtkWidget * account_scu;
-  
-  GList * valid_types;
+
+  guint32 valid_types;
+  GNCAccountType preferred_account_type;
   GtkWidget * type_view;
   GtkTreeView * parent_tree;
 
@@ -121,13 +122,12 @@ typedef struct _RenumberDialog
 /** Static Globals *******************************************************/
 static QofLogModule log_module = GNC_MOD_GUI;
 
-static int last_used_account_type = BANK;
+static GNCAccountType last_used_account_type = BANK;
 
 static GList *ac_destroy_cb_list = NULL;
 
 /** Declarations *********************************************************/
 static void gnc_account_window_set_name (AccountWindow *aw);
-static void make_account_changes(GHashTable *change_type);
 
 void gnc_account_renumber_prefix_changed_cb (GtkEditable *editable, RenumberDialog *data);
 void gnc_account_renumber_interval_changed_cb (GtkSpinButton *spinbutton, RenumberDialog *data);
@@ -233,9 +233,6 @@ gnc_account_to_ui(AccountWindow *aw)
   flag = xaccAccountGetHidden (account);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (aw->hidden_button),
                                 flag);
-
-  gtk_tree_view_collapse_all (aw->parent_tree);
-  gnc_tree_view_account_set_selected_account (GNC_TREE_VIEW_ACCOUNT(aw->parent_tree), account);
   LEAVE(" ");
 }
 
@@ -313,11 +310,18 @@ gnc_ui_to_account(AccountWindow *aw)
     return;
   }
 
+  if (aw->type != xaccAccountGetType (account)) {
+    /* Just refreshing won't work. */
+    aw_call_destroy_callbacks (account);
+  }
+
   xaccAccountBeginEdit (account);
 
   if (aw->type != xaccAccountGetType (account))
     xaccAccountSetType (account, aw->type);
 
+  last_used_account_type = aw->type;
+
   string = gtk_entry_get_text (GTK_ENTRY(aw->name_entry));
   old_string = xaccAccountGetName (account);
   if (safe_strcmp (string, old_string) != 0)
@@ -428,15 +432,57 @@ gnc_ui_to_account(AccountWindow *aw)
 }
 
 
-static void 
-gnc_finish_ok (AccountWindow *aw,
-               GHashTable *change_type)
+static void
+set_children_types (Account *account, GNCAccountType type)
 {
-  ENTER("aw %p, hash table %p", aw, change_type);
+  AccountGroup *children;
+  GList *iter;
+
+  children = xaccAccountGetChildren (account);
+  if (children == NULL)
+    return;
+
+  for (iter=xaccGroupGetAccountList (children); iter; iter=iter->next) {
+    account = iter->data;
+    if (type == xaccAccountGetType(account))
+      continue;
+
+    /* Just refreshing won't work. */
+    aw_call_destroy_callbacks (account);
+
+    xaccAccountBeginEdit (account);
+    xaccAccountSetType (account, type);
+    xaccAccountCommitEdit (account);
+
+    set_children_types (account, type);
+  }
+}
+
+static void
+make_children_compatible (AccountWindow *aw)
+{
+  Account *account;
+
+  g_return_if_fail (aw);
+
+  account = aw_get_account (aw);
+  g_return_if_fail (account);
+
+  if (xaccAccountTypesCompatible (xaccAccountGetType (account), aw->type))
+    return;
+
+  set_children_types (account, aw->type);
+}
+
+
+static void
+gnc_finish_ok (AccountWindow *aw)
+{
+  ENTER("aw %p", aw);
   gnc_suspend_gui_refresh ();
 
   /* make the account changes */
-  make_account_changes (change_type);
+  make_children_compatible (aw);
   gnc_ui_to_account (aw);
 
   gnc_resume_gui_refresh ();
@@ -486,156 +532,43 @@ gnc_finish_ok (AccountWindow *aw,
 }
 
 
-/* Record all of the children of the given account as needing their
- * type changed to the one specified. */
 static void
-gnc_edit_change_account_types(GHashTable *change_type, Account *account,
-                              Account *except, GNCAccountType type)
+add_children_to_expander (GObject *object, GParamSpec *param_spec, gpointer data)
 {
-  AccountGroup *children;
-  GList *list;
-  GList *node;
+  GtkExpander *expander = GTK_EXPANDER (object);
+  Account *account = data;
+  GtkWidget *scrolled_window;
+  GtkTreeView *view;
 
-  if ((change_type == NULL) || (account == NULL))
-    return;
+  if (gtk_expander_get_expanded (expander) &&
+      !gtk_bin_get_child (GTK_BIN (expander))) {
 
-  if (account == except)
-    return;
+    view = gnc_tree_view_account_new_with_group (
+      xaccAccountGetChildren (account), FALSE);
 
-  g_hash_table_insert(change_type, account, GINT_TO_POINTER(type));
+    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
+                                         GTK_SHADOW_IN);
+    gtk_container_add (GTK_CONTAINER (scrolled_window), GTK_WIDGET (view));
 
-  children = xaccAccountGetChildren(account);
-  if (children == NULL)
-    return;
-
-  list = xaccGroupGetAccountList (children);
-
-  for (node= list; node; node = node->next)
-  {
-    account = node->data;
-    gnc_edit_change_account_types(change_type, account, except, type);
+    gtk_container_add (GTK_CONTAINER (expander), scrolled_window);
+    gtk_widget_show_all (scrolled_window);
   }
 }
 
-
-/* helper function to perform changes to accounts */
-static void
-change_func (gpointer key, gpointer value, gpointer unused)
-{
-  Account *account = key;
-  int type;
- 
-  if (account == NULL)
-    return;
-
-  xaccAccountBeginEdit(account);
-
-  type = GPOINTER_TO_INT(value);
-
-  if (type == xaccAccountGetType(account))
-    return;
-
-  /* Just refreshing won't work. */
-  aw_call_destroy_callbacks (account);
-
-  xaccAccountSetType(account, type);
-
-  xaccAccountCommitEdit(account);
-}
-
-
-/* Perform the changes to accounts dictated by the hash tables */
-static void
-make_account_changes(GHashTable *change_type)
-{
-  if (change_type != NULL)
-    g_hash_table_foreach(change_type, change_func, NULL);
-}
-
-
-typedef struct
-{
-  Account *account;
-  GtkCList *list;
-  guint count;
-} FillStruct;
-
-static void
-fill_helper(gpointer key, gpointer value, gpointer data)
-{
-  Account *account = key;
-  FillStruct *fs = data;
-  gchar *full_name;
-  gchar *account_field_name;
-  gchar *account_field_value;
-  gchar *value_str;
-
-  if (fs == NULL) return;
-  if (fs->account == account) return;
-
-  full_name = xaccAccountGetFullName(account);
-  if(!full_name)
-    full_name = g_strdup("");
-
-  account_field_name = g_strdup("Type");
-  if (!account_field_name)
-    account_field_name = g_strdup("");
-
-  account_field_value =
-    g_strdup (xaccAccountGetTypeStr(xaccAccountGetType(account)));
-  if (!account_field_value)
-    account_field_value = g_strdup("");
-
-  value_str = g_strdup(xaccAccountGetTypeStr(GPOINTER_TO_INT(value)));
-
-  {  
-    gchar *strings[5];
-
-    strings[0] = full_name;
-    strings[1] = account_field_name;
-    strings[2] = account_field_value;
-    strings[3] = value_str;
-    strings[4] = NULL; 
-
-    gtk_clist_append(fs->list, strings);
-  }
-
-  g_free(full_name);
-  g_free(account_field_name);
-  g_free(account_field_value);
-  g_free(value_str);
-  fs->count++;
-}
-
-static guint
-fill_list(Account *account, GtkCList *list,
-          GHashTable *change)
-{
-  FillStruct fs;
-
-  if (change == NULL)
-    return 0;
-
-  fs.account = account;
-  fs.list = list;
-  fs.count = 0;
-
-  g_hash_table_foreach(change, fill_helper, &fs);
-
-  return fs.count;
-}
-
-
-/* Present a dialog of proposed account changes for the user's ok */
+/* Check whether there are children needing a type adjustment because of a
+   a change to an incompatible type (like after some reparenting) and let the
+   user decide whether he wants that */
 static gboolean
-extra_change_verify (AccountWindow *aw,
-                     GHashTable *change_type)
+verify_children_compatible (AccountWindow *aw)
 {
   Account *account;
-  GtkCList *list;
-  gchar *titles[5];
+  AccountGroup *children;
+  GtkWidget *dialog, *vbox, *hbox, *label, *expander;
+  gchar *str;
   gboolean result;
-  guint size;
 
   if (aw == NULL)
     return FALSE;
@@ -644,69 +577,88 @@ extra_change_verify (AccountWindow *aw,
   if (!account)
     return FALSE;
 
-  titles[0] = _("Account");
-  titles[1] = _("Field");
-  titles[2] = _("Old Value");
-  titles[3] = _("New Value");
-  titles[4] = NULL;
-
-  list = GTK_CLIST(gtk_clist_new_with_titles(4, titles));
-
-  size = 0;
-  size += fill_list(account, list, change_type);
-
-  if (size == 0)
-  {
-    gtk_widget_destroy(GTK_WIDGET(list));
+  if (xaccAccountTypesCompatible (xaccAccountGetType (account), aw->type))
     return TRUE;
-  }
 
-  gtk_clist_column_titles_passive(list);
-  gtk_clist_set_sort_column(list, 0);
-  gtk_clist_sort(list);
-  gtk_clist_columns_autosize(list);
+  children = xaccAccountGetChildren (account);
+  if (!children ||
+      !xaccGroupGetNumAccounts (children))
+    return TRUE;
 
+  dialog = gtk_dialog_new_with_buttons ("",
+                                        GTK_WINDOW(aw->dialog),
+                                        GTK_DIALOG_DESTROY_WITH_PARENT |
+                                        GTK_DIALOG_MODAL,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                                        NULL);
+
+  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), TRUE);
+
+  hbox = gtk_hbox_new (FALSE, 12);
+  vbox = gtk_vbox_new (FALSE, 12);
+
+  gtk_box_pack_start (
+    GTK_BOX (hbox),
+    gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG),
+    FALSE, FALSE, 0);
+
+  /* primary label */
+  label = gtk_label_new (_("Give the children the same type?"));
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+  gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
   {
-    GtkWidget *dialog;
-    GtkWidget *scroll;
-    GtkWidget *label;
-    GtkWidget *frame;
-    GtkWidget *vbox;
+    gint size;
+    PangoFontDescription *font_desc;
 
-    dialog = gtk_dialog_new_with_buttons (_("Verify Changes"),
-		    			  GTK_WINDOW(aw->dialog),
-					  GTK_DIALOG_DESTROY_WITH_PARENT |
-					  GTK_DIALOG_MODAL,
-					  GTK_STOCK_OK, GTK_RESPONSE_OK,
-					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					  NULL);
-
-    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-    gtk_window_set_default_size (GTK_WINDOW (dialog), 0, 300);
-
-    vbox = GTK_DIALOG (dialog)->vbox;
-
-    label = gtk_label_new(_("The following changes must be made. Continue?"));
-    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 0);
-
-    scroll = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
-                                   GTK_POLICY_NEVER, 
-                                   GTK_POLICY_AUTOMATIC);
-
-    gtk_container_add(GTK_CONTAINER(frame), scroll);
-    gtk_container_set_border_width(GTK_CONTAINER(scroll), 5);
-    gtk_container_add(GTK_CONTAINER(scroll), GTK_WIDGET(list));
-
-    gtk_widget_show_all(vbox);
-
-    result = (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK);
-
-    gtk_widget_destroy(dialog);
+    size = pango_font_description_get_size (label->style->font_desc);
+    font_desc = pango_font_description_new ();
+    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
+    pango_font_description_set_size (font_desc, size * PANGO_SCALE_LARGE);
+    gtk_widget_modify_font (label, font_desc);
+    pango_font_description_free (font_desc);
   }
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+  /* secondary label */
+  str = g_strdup_printf (_("The children of the edited account have to be "
+                           "changed to type \"%s\" to make them compatible."),
+                         xaccAccountGetTypeStr (aw->type));
+  label = gtk_label_new (str);
+  g_free (str);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+  gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+  /* children */
+  expander = gtk_expander_new_with_mnemonic (_("_Show children accounts"));
+  gtk_expander_set_spacing (GTK_EXPANDER (expander), 6);
+  g_signal_connect (G_OBJECT (expander), "notify::expanded",
+                    G_CALLBACK (add_children_to_expander), account);
+  gtk_box_pack_start (GTK_BOX (vbox), expander, TRUE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
+
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
+                      TRUE, TRUE, 0);
+
+  /* spacings */
+  gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+  gtk_container_set_border_width (
+    GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->action_area), 6);
+
+  gtk_widget_show_all (hbox);
+
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+
+  result = (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK);
+
+  gtk_widget_destroy(dialog);
 
   return result;
 }
@@ -798,6 +750,16 @@ gnc_common_ok (AccountWindow *aw)
     return FALSE;
   }
 
+  /* check whether the types of child and parent are compatible */
+  if (parent != aw->top_level_account &&
+      !xaccAccountTypesCompatible (aw->type, xaccAccountGetType (parent))) {
+    const char *message = _("The selected account type is incompatible with "
+                            "the one of the selected parent.");
+    gnc_error_dialog(aw->dialog, message);
+    LEAVE("incompatible types");
+    return FALSE;
+  }
+
   /* check for commodity */
   commodity = (gnc_commodity *)
     gnc_general_select_get_selected (GNC_GENERAL_SELECT (aw->commodity_edit));
@@ -815,17 +777,7 @@ gnc_common_ok (AccountWindow *aw)
 static void
 gnc_edit_account_ok(AccountWindow *aw)
 {
-  GHashTable *change_type;
-
-  gboolean change_children;
-  gboolean has_children;
-  gboolean change_all;
-
-  Account *new_parent;
   Account *account;
-  AccountGroup *children;
-
-  GNCAccountType current_type;
 
   ENTER("aw %p", aw);
 
@@ -840,73 +792,12 @@ gnc_edit_account_ok(AccountWindow *aw)
     return;
   }
 
-  change_type = g_hash_table_new (NULL, NULL);
-
-  children = xaccAccountGetChildren(account);
-  if (children == NULL)
-    has_children = FALSE;
-  else if (xaccGroupGetNumAccounts(children) == 0)
-    has_children = FALSE;
-  else
-    has_children = TRUE;
-
-  current_type = xaccAccountGetType(account);
-
-  /* If the account has children and the new type isn't compatible
-   * with the old type, the children's types must be changed. */
-  change_children = (has_children &&
-                     !xaccAccountTypesCompatible(current_type, aw->type));
-
-  /* If the new parent's type is not compatible with the new type,
-   * the whole sub-tree containing the account must be re-typed. */
-  new_parent = gnc_tree_view_account_get_selected_account (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
-  if (new_parent != aw->top_level_account)
-  {
-    int parent_type;
-
-    parent_type = xaccAccountGetType(new_parent);
-
-    if (!xaccAccountTypesCompatible(parent_type, aw->type))
-      change_all = TRUE;
-    else
-      change_all = FALSE;
-  }
-  else
-    change_all = FALSE;
-
-  if (change_children)
-    gnc_edit_change_account_types(change_type, account, NULL, aw->type);
-
-  if (change_all)
-  {
-    Account *ancestor;
-    Account *temp;
-
-    temp = new_parent;
-
-    do
-    {
-      ancestor = temp;
-      temp = xaccAccountGetParentAccount(ancestor);
-    } while (temp != NULL);
-
-    gnc_edit_change_account_types(change_type, ancestor, account, aw->type);
-  }
-
-  if (!extra_change_verify(aw, change_type))
-  {
-    g_hash_table_destroy(change_type);
+  if (!verify_children_compatible (aw)) {
     LEAVE(" ");
     return;
   }
 
-  if (current_type != aw->type)
-    /* Just refreshing won't work. */
-    aw_call_destroy_callbacks (account);
-
-  gnc_finish_ok (aw, change_type);
-
-  g_hash_table_destroy (change_type);
+  gnc_finish_ok (aw);
     LEAVE(" ");
 }
 
@@ -958,7 +849,7 @@ gnc_new_account_ok (AccountWindow *aw)
     }
   }
 
-  gnc_finish_ok (aw, NULL);
+  gnc_finish_ok (aw);
   LEAVE(" ");
 }
 
@@ -1056,11 +947,63 @@ gnc_account_window_destroy_cb (GtkObject *object, gpointer data)
     aw->next_name = NULL;
   }
 
-  g_list_free (aw->valid_types);
   g_free (aw);
   LEAVE(" ");
 }
 
+static void
+gnc_account_parent_changed_cb (GtkTreeSelection *selection, gpointer data)
+{
+  AccountWindow *aw = data;
+  Account *parent_account;
+  guint32 types, old_types;
+  GtkTreeModel *type_model;
+  GtkTreeSelection *type_selection;
+  gboolean scroll_to = FALSE;
+
+  g_return_if_fail (aw);
+
+  parent_account = gnc_tree_view_account_get_selected_account (
+    GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
+  if (!parent_account)
+    return;
+
+  if (parent_account == aw->top_level_account) {
+    types = aw->valid_types;
+  } else {
+    types = aw->valid_types &
+      xaccAccountTypesCompatibleWith (xaccAccountGetType (parent_account));
+  }
+
+  type_model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->type_view));
+  if (!type_model)
+    return;
+
+  if (aw->type != aw->preferred_account_type &&
+      (types & (1 << aw->preferred_account_type)) != 0) {
+    /* we can change back to the preferred account type */
+    aw->type = aw->preferred_account_type;
+    scroll_to = TRUE;
+  }
+  else if ((types & (1 << aw->type)) == 0) {
+    /* our type is invalid now */
+    aw->type = BAD_TYPE;
+  }
+  else {
+    /* no type change, but maybe list of valid types changed */
+    old_types = gnc_tree_model_account_types_get_mask (type_model);
+    if (old_types != types)
+      scroll_to = TRUE;
+  }
+
+  gnc_tree_model_account_types_set_mask (type_model, types);
+
+  if (scroll_to) {
+    type_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->type_view));
+    gnc_tree_model_account_types_set_selection(type_selection, 1 << aw->type);
+  }
+}
+
 static void
 gnc_account_type_changed_cb (GtkTreeSelection *selection, gpointer data)
 {
@@ -1077,7 +1020,7 @@ gnc_account_type_changed_cb (GtkTreeSelection *selection, gpointer data)
     aw->type = BAD_TYPE;
   } else {
     aw->type = type_id;
-    last_used_account_type = type_id;
+    aw->preferred_account_type = type_id;
 
     gnc_account_commodity_from_type (aw, TRUE);
 
@@ -1095,18 +1038,6 @@ gnc_account_type_changed_cb (GtkTreeSelection *selection, gpointer data)
   }
 }
 
-static GNCAccountType
-gnc_account_choose_new_acct_type (AccountWindow *aw)
-{
-  if (g_list_index (aw->valid_types, GINT_TO_POINTER(aw->type)) != -1)
-    return aw->type;
-
-  if (g_list_index (aw->valid_types, GINT_TO_POINTER(last_used_account_type)) != -1)
-    return last_used_account_type;
-
-  return ((GNCAccountType)(aw->valid_types->data));
-}
-
 static void
 gnc_account_type_view_create (AccountWindow *aw)
 {
@@ -1114,19 +1045,34 @@ gnc_account_type_view_create (AccountWindow *aw)
   GtkTreeSelection *selection;
   GtkCellRenderer *renderer;
   GtkTreeView *view;
-  GList *list;
-  guint32 types = 0;
 
-  if ((aw->dialog_type == NEW_ACCOUNT) && aw->valid_types)
-    aw->type = gnc_account_choose_new_acct_type (aw);
+  if (aw->valid_types == 0) {
+    /* no type restrictions, choose aw->type */
+    aw->valid_types = xaccAccountTypesValid () | (1 << aw->type);
+    aw->preferred_account_type = aw->type;
+  }
+  else if ((aw->valid_types & (1 << aw->type)) != 0) {
+    /* aw->type is valid */
+    aw->preferred_account_type = aw->type;
+  }
+  else if ((aw->valid_types & (1 << last_used_account_type)) != 0) {
+    /* last used account type is valid */
+    aw->type = last_used_account_type;
+    aw->preferred_account_type = last_used_account_type;
+  }
+  else {
+    /* choose first valid account type */
+    int i;
+    aw->preferred_account_type = aw->type;
+    aw->type = BAD_TYPE;
+    for (i=0; i<32; i++)
+      if ((aw->valid_types & (1 << i)) != 0) {
+        aw->type = i;
+        break;
+      }
+  }
 
-  if (aw->valid_types == NULL)
-      types = xaccAccountTypesValid () | (1 << aw->type);
-  else
-      for (list = aw->valid_types; list; list = list->next)
-          types |= (1 << GPOINTER_TO_INT(list->data));
-
-  model = gnc_tree_model_account_types_filter_using_mask (types);
+  model = gnc_tree_model_account_types_filter_using_mask (aw->valid_types);
 
   view = GTK_TREE_VIEW (aw->type_view);
   gtk_tree_view_set_model (view, model);
@@ -1142,7 +1088,7 @@ gnc_account_type_view_create (AccountWindow *aw)
   selection = gtk_tree_view_get_selection (view);
   g_signal_connect (G_OBJECT (selection), "changed",
 		    G_CALLBACK (gnc_account_type_changed_cb), aw);
-  
+
   gnc_tree_model_account_types_set_selection(selection, 1 << aw->type);
 }
 
@@ -1226,7 +1172,6 @@ opening_equity_cb (GtkWidget *w, gpointer data)
 static void
 gnc_account_window_create(AccountWindow *aw)
 {
-  GtkDialog *awd;
   GtkWidget *amount;
   GObject *awo;
   GtkWidget *box;
@@ -1239,7 +1184,6 @@ gnc_account_window_create(AccountWindow *aw)
 
   aw->dialog = glade_xml_get_widget (xml, "Account Dialog");
   awo = G_OBJECT (aw->dialog);
-  awd = GTK_DIALOG (awo);
 
   g_object_set_data (awo, "dialog_info", aw);
 
@@ -1285,6 +1229,9 @@ gnc_account_window_create(AccountWindow *aw)
   aw->parent_tree = gnc_tree_view_account_new(TRUE);
   gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(aw->parent_tree));
   gtk_widget_show(GTK_WIDGET(aw->parent_tree));
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->parent_tree));
+  g_signal_connect (G_OBJECT (selection), "changed",
+                    G_CALLBACK (gnc_account_parent_changed_cb), aw);
   aw->top_level_account =
     gnc_tree_view_account_get_top_level (GNC_TREE_VIEW_ACCOUNT(aw->parent_tree));
 
@@ -1476,12 +1423,16 @@ gnc_ui_new_account_window_internal (Account *base_account,
   gnc_commodity *commodity, *parent_commodity;
   AccountWindow *aw;
   Account *account;
+  GList *list;
 
   aw = g_new0 (AccountWindow, 1);
 
   aw->modal = modal;
   aw->dialog_type = NEW_ACCOUNT;
-  aw->valid_types = g_list_copy (valid_types);
+
+  aw->valid_types = 0;
+  for (list = valid_types; list; list = list->next)
+    aw->valid_types |= (1 << GPOINTER_TO_INT (list->data));
 
   account = xaccMallocAccount (gnc_get_current_book ());
   aw->account = *xaccAccountGetGUID (account);
@@ -1519,15 +1470,14 @@ gnc_ui_new_account_window_internal (Account *base_account,
                                     commodity);
   gnc_account_commodity_from_type (aw, FALSE);
 
-  gtk_widget_show (aw->dialog);
-
-  if (base_account == NULL) {
-	  base_account = aw->top_level_account;
-  }
+  if (base_account == NULL)
+    base_account = aw->top_level_account;
 
   gtk_tree_view_collapse_all (aw->parent_tree);
-  gnc_tree_view_account_set_selected_account (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree),
-					      base_account);
+  gnc_tree_view_account_set_selected_account (
+    GNC_TREE_VIEW_ACCOUNT (aw->parent_tree), base_account);
+
+  gtk_widget_show (aw->dialog);
 
   gnc_window_adjust_for_screen (GTK_WINDOW(aw->dialog));
 
@@ -1536,7 +1486,7 @@ gnc_ui_new_account_window_internal (Account *base_account,
   aw->component_id = gnc_register_gui_component (DIALOG_NEW_ACCOUNT_CM_CLASS,
                                                  refresh_handler,
                                                  modal ? NULL : close_handler,
-						 aw);
+                                                 aw);
 
   gnc_gui_component_set_session (aw->component_id, gnc_get_current_session());
   gnc_gui_component_watch_entity_type (aw->component_id,
@@ -1604,10 +1554,11 @@ gnc_ui_new_accounts_from_name_window_with_types (const char *name,
   return gnc_ui_new_accounts_from_name_with_defaults(name, valid_types, NULL, NULL);
 }
 
-Account * gnc_ui_new_accounts_from_name_with_defaults (const char *name,
-						       GList *valid_types,
-						       gnc_commodity * default_commodity,
-						       Account * parent)
+Account *
+gnc_ui_new_accounts_from_name_with_defaults (const char *name,
+                                             GList *valid_types,
+                                             gnc_commodity * default_commodity,
+                                             Account * parent)
 {
   AccountWindow *aw;
   Account *base_account = NULL;
@@ -1721,7 +1672,9 @@ gnc_ui_edit_account_window(Account *account)
   if (parent == NULL)
     parent = aw->top_level_account;
 
-  gnc_tree_view_account_set_selected_account (GNC_TREE_VIEW_ACCOUNT(aw->parent_tree), parent);
+  gtk_tree_view_collapse_all (aw->parent_tree);
+  gnc_tree_view_account_set_selected_account (
+    GNC_TREE_VIEW_ACCOUNT(aw->parent_tree), parent);
 
   gnc_account_window_set_name (aw);
 
@@ -1769,16 +1722,7 @@ void
 gnc_ui_new_account_with_types( AccountGroup *unused,
                                GList *valid_types )
 {
-  GList *validTypesCopy = g_list_copy( valid_types );
-  AccountWindow *aw;
-
-  aw = gnc_ui_new_account_window_internal( NULL, NULL, validTypesCopy, NULL, FALSE );
-  if ( validTypesCopy != NULL ) {
-    /* Attach it with "[...]_full" so we can set the appropriate
-     * GtkDestroyNotify func. */
-    g_object_set_data_full( G_OBJECT(aw->dialog), "validTypesListCopy",
-			    validTypesCopy, (GDestroyNotify)g_list_free );
-  }
+  gnc_ui_new_account_window_internal( NULL, NULL, valid_types, NULL, FALSE );
 }
 
 /************************************************************
