@@ -47,6 +47,7 @@
 
 
 #define DIALOG_TRANSFER_CM_CLASS "dialog-transfer"
+#define GCONF_SECTION "dialogs/transfer"
 
 #define PRECISION 1000000
 
@@ -1648,6 +1649,7 @@ gnc_xfer_dialog_create(GtkWidget *parent, XferDialog *xferData)
 
   dialog = glade_xml_get_widget (xml, "Transfer Dialog");
   xferData->dialog = dialog;
+  g_object_set_data_full (G_OBJECT (dialog), "xml", xml, g_object_unref);
 
   /* parent */
   if (parent != NULL)
@@ -1824,6 +1826,7 @@ gnc_xfer_dialog_create(GtkWidget *parent, XferDialog *xferData)
 			 _("To Amount:"));
     }
   }
+  gnc_restore_window_size (GCONF_SECTION, GTK_WINDOW (dialog));
   LEAVE(" ");
 }
 
@@ -1836,6 +1839,7 @@ close_handler (gpointer user_data)
   ENTER(" ");
   dialog = GTK_WIDGET (xferData->dialog);
 
+  gnc_save_window_size (GCONF_SECTION, GTK_WINDOW (dialog));
   gtk_widget_hide (dialog);
   gnc_xfer_dialog_close_cb(GTK_DIALOG(dialog), xferData);
   gtk_widget_destroy (dialog);
