@@ -166,15 +166,17 @@ static GtkWidgetClass *parent_class = NULL;
  * locale. (i18n'd version of the above static character array.) */
 static const gchar *month_name(int mon) 
 {
-    static gchar buf[MONTH_NAME_BUFSIZE];
-    struct tm my_tm;
-    int i;
+        static gchar buf[MONTH_NAME_BUFSIZE];
+        GDate date;
 
-    memset( buf, 0, MONTH_NAME_BUFSIZE );
-    memset( &my_tm, 0, sizeof( struct tm ) );
-    my_tm.tm_mon = mon;
-    i = strftime (buf, MONTH_NAME_BUFSIZE-1, "%b", &my_tm);
-    return buf;
+        memset(buf, 0, MONTH_NAME_BUFSIZE);
+        g_date_clear(&date, 1);
+	g_date_set_time_t(&date, time(NULL));
+	// g_date API is 1..12 (not 0..11)
+        g_date_set_month(&date, mon+1);
+        g_date_strftime(buf, MONTH_NAME_BUFSIZE-1, "%b", &date);
+
+        return buf;
 }
 /* FIXME: i18n 
    static const gchar *dayLabels[7] = {
