@@ -900,7 +900,7 @@ gnc_file_export_file(const char * newfile)
   /* -- this session code is NOT identical in FileOpen and FileSaveAs -- */
 
   new_session = qof_session_new ();
-  qof_session_begin (new_session, newfile, FALSE, FALSE);
+  qof_session_begin (new_session, newfile, FALSE, TRUE);
 
   io_err = qof_session_get_error (new_session);
 
@@ -1169,5 +1169,6 @@ gnc_file_set_shutdown_callback (GNCShutdownCB cb)
 gboolean
 gnc_file_save_in_progress (void)
 {
-  return (save_in_progress > 0);
+    QofSession *session = gnc_get_current_session();
+    return (qof_session_save_in_progress(session) || save_in_progress > 0);
 }
