@@ -1,6 +1,7 @@
 /********************************************************************\
  * gnc-frequency.c -- GnuCash widget for frequency editing.         *
  * Copyright (C) 2001,2002 Joshua Sled <jsled@asynchronous.org>     *
+ * Copyright (C) 2003 Linas Vepstas <linas@linas.org>               *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -16,25 +17,26 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
 
 #include "config.h"
 
-#include <glib.h>
+#include <gtk/gtk.h>
+#include "glib-compat.h"
 #include <math.h>
 #include <time.h>
 
 #include "FreqSpec.h"
 #include "dialog-utils.h"
 #include "gnc-component-manager.h"
-#include "gnc-engine-util.h"
+#include "gnc-engine.h"
 #include "gnc-frequency.h"
 #include "gnc-ui-util.h"
 
-static short module = MOD_SX;
+static QofLogModule log_module = GNC_MOD_SX;
 
 /** Private Defs ********************/
 
@@ -43,7 +45,7 @@ typedef enum {
   LAST_SIGNAL
 } GNCF_Signals;
 
-static gint gnc_frequency_signals[LAST_SIGNAL] = { 0 };
+static guint gnc_frequency_signals[LAST_SIGNAL] = { 0 };
 
 /** Private Prototypes ********************/
 
@@ -69,7 +71,7 @@ static void year_range_sels_changed( GNCFrequency *gf,
 static void year_range_menu_helper( GtkWidget *dayOptMenu,
                                     GtkWidget *occurOptMenu,
                                     gint monthsInRange,
-                                    time_t startDate );
+                                    time_t date );
 
 /** Static Inits ********************/
 
@@ -102,46 +104,48 @@ static const char *CHECKBOX_NAMES[] = {
 
 /** Implementations ********************/
 
-guint
+GType
 gnc_frequency_get_type()
 {
-        static guint gncfreq_type = 0;
-        if ( ! gncfreq_type ) {
-                GtkTypeInfo gncfreq_info =
-                        {
-                                "GNCFrequency",
-                                sizeof(GNCFrequency),
-                                sizeof(GNCFrequencyClass),
-                                (GtkClassInitFunc)gnc_frequency_class_init,
-                                (GtkObjectInitFunc)gnc_frequency_init,
-                                (GtkArgSetFunc)NULL,
-                                (GtkArgGetFunc)NULL
-                        };
-    
-                gncfreq_type = gtk_type_unique( gtk_vbox_get_type(), &gncfreq_info );
+	static GType gncfreq_type = 0;
+        if (gncfreq_type == 0) {
+                static GTypeInfo gncfreq_info = {
+			sizeof(GNCFrequencyClass),
+			NULL,
+			NULL,
+			(GClassInitFunc)gnc_frequency_class_init,
+			NULL,
+			NULL,
+			sizeof(GNCFrequency),
+			0,
+			(GInstanceInitFunc)gnc_frequency_init
+		};
+
+                gncfreq_type = g_type_register_static (GTK_TYPE_VBOX,
+						       "GNCFrequency",
+						       &gncfreq_info, 0);
         }
-        return gncfreq_type;
+
+	return gncfreq_type;
 }
 
 static void
 gnc_frequency_class_init( GNCFrequencyClass *klass )
 {
-        GtkObjectClass *objectClass;
+	GObjectClass *object_class;
+	
+	object_class = G_OBJECT_CLASS (klass);
 
-
-        objectClass = (GtkObjectClass*)klass;
         gnc_frequency_signals[GNCFREQ_CHANGED] =
-                gtk_signal_new( "changed",
-                                GTK_RUN_FIRST,
-                                objectClass->type,
-                                GTK_SIGNAL_OFFSET( GNCFrequencyClass, changed ),
-                                gtk_signal_default_marshaller, GTK_TYPE_NONE, 0 );
-
-        gtk_object_class_add_signals( objectClass,
-                                      gnc_frequency_signals,
-                                      LAST_SIGNAL );
-
-        klass->changed = NULL;
+		g_signal_new ("changed",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (GNCFrequencyClass, changed),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 }
 
 void
@@ -211,98 +215,82 @@ gnc_frequency_init( GNCFrequency *gf )
                         /* FIXME: having the user-data be a struct of a
                          * calendar name and the GNCFrequency would allow a
                          * single callback fn */
-                        gtk_signal_connect( GTK_OBJECT(o), "selection-done",
-                                            GTK_SIGNAL_FUNC(optionMenus[i].fn), gf );
+                        g_signal_connect( o, "selection-done",
+					  G_CALLBACK(optionMenus[i].fn), gf );
                 }
         }
 
         /* initialize the spin buttons */
-        for ( i=0; spinVals[i].name != NULL; i++ ) {
-                o = glade_xml_get_widget( gf->gxml,
+        for ( i=0; spinVals[i].name != NULL; i++ ) 
+        {
+                if ( spinVals[i].fn != NULL ) 
+                {
+                        o = glade_xml_get_widget( gf->gxml,
                                           spinVals[i].name );
-                if ( spinVals[i].fn != NULL ) {
                         adj = gtk_spin_button_get_adjustment( GTK_SPIN_BUTTON(o) );
-                        gtk_signal_connect( GTK_OBJECT(adj), "value_changed",
-                                            GTK_SIGNAL_FUNC(spinVals[i].fn), gf );
+                        g_signal_connect( adj, "value_changed",
+					  G_CALLBACK(spinVals[i].fn), gf );
                 }
         }
 
         /* initialize the weekly::day-of-week checkbox-selection hooks */
         for ( i=0; i<7; i++ ) {
                 o = glade_xml_get_widget( gf->gxml, CHECKBOX_NAMES[i] );
-                gtk_signal_connect( GTK_OBJECT(o), "clicked",
-                                    GTK_SIGNAL_FUNC(weekly_days_changed), gf );
+                g_signal_connect( o, "clicked",
+				  G_CALLBACK(weekly_days_changed), gf );
         }
 
         gtk_widget_show_all( GTK_WIDGET(&gf->widget) );
 
         /* respond to start date changes */
-        gtk_signal_connect( GTK_OBJECT(gf->startDate), "date_changed",
-                            GTK_SIGNAL_FUNC(start_date_changed), gf );
+        g_signal_connect( gf->startDate, "date_changed",
+			  G_CALLBACK(start_date_changed), gf );
 
 }
 
-GtkWidget *
-gnc_frequency_new( FreqSpec *fs, GDate *startDate )
-{
-        GNCFrequency  *toRet;
-        toRet = gtk_type_new( gnc_frequency_get_type() );
-        gnc_frequency_setup( toRet, fs, startDate );
-        return GTK_WIDGET(toRet);
-}
-
-void
-gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
+static void
+do_frequency_setup( GNCFrequency *gf, FreqSpec *fs, time_t *secs)
 {
         UIFreqType uift;
-        int page;
-        time_t tmpTT;
-        struct tm *tmpTm = NULL;
-        GtkWidget *o;
-        FreqSpec *subFS;
-        GList *list;
-        int i;
-        const char *str;
+        int i, page;
 
-        page = -1;
-        if ( fs != NULL ) {
-                uift = xaccFreqSpecGetUIType( fs );
-        } else {
-                uift = UIFREQ_NONE;
+        /* Set the start date, but only if present. */
+        if (secs)
+        {
+                gnc_date_edit_set_time( gf->startDate, *secs);
+                if (NULL == fs) 
+                {
+                        g_signal_emit_by_name( gf, "changed" );
+                }
         }
+ 
+        /* If freq spec not present, then we are done; 
+         * don't change any other settings.  */
+        if (NULL == fs) return;
 
-        for ( i=0; i < UIFREQ_NUM_UI_FREQSPECS+1; i++ ) {
-                if ( PAGES[i].uiFTVal == uift ) {
-                        page = PAGES[i].idx;
+        uift = xaccFreqSpecGetUIType( fs );
+        page = -1;
+        for ( i=0; i < UIFREQ_NUM_UI_FREQSPECS+1; i++ ) 
+        {
+                if ( PAGES[i].uiFTVal == uift ) 
+                {
+                         page = PAGES[i].idx;
+                         break;
                 }
         }
         g_assert( page != -1 );
 
-        gtk_notebook_set_page( gf->nb, page );
+        gtk_notebook_set_current_page( gf->nb, page );
         gtk_option_menu_set_history( gf->freqOpt, page );
 
-        if ( fs == NULL ) {
-                return;
-        }
-
-        /* setup the start date */
-        if ( ! g_date_valid(startDate) ) {
-                tmpTT = time(NULL);
-        } else {
-                tmpTm = g_new0( struct tm, 1 );
-                g_date_to_struct_tm( startDate, tmpTm );
-                tmpTT = mktime( tmpTm );
-                g_free( tmpTm );
-        }
-        gnc_date_edit_set_time( gf->startDate, tmpTT );
- 
-        switch ( uift ) {
+        switch ( uift ) 
+        {
         case UIFREQ_NONE:
                 break;
         case UIFREQ_ONCE:
         {
                 GDate theDate;
-                tmpTm = g_new0( struct tm, 1 );
+                struct tm stm;
                 /* set the date */
                 if ( xaccFreqSpecGetOnce( fs, &theDate ) < 0 ) {
                         PERR( "Inappropriate FreqSpec type "
@@ -310,13 +298,13 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
                               uift, xaccFreqSpecGetUIType( fs ) );
                         return;
                 }
-                g_date_to_struct_tm( &theDate, tmpTm );
-                gnc_date_edit_set_time( gf->startDate, mktime(tmpTm) );
-                g_free( tmpTm );
+                g_date_to_struct_tm( &theDate, &stm );
+                gnc_date_edit_set_time( gf->startDate, mktime(&stm) );
         }
         break;
         case UIFREQ_DAILY:
         { 
+                GtkWidget *o;
                 int dailyMult = -1;
                 if ( xaccFreqSpecGetDaily( fs, &dailyMult ) < 0 ) {
                         PERR( "Inappropriate FreqSpec type "
@@ -330,6 +318,7 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
         break;
         case UIFREQ_DAILY_MF:
         {
+                GtkWidget *o;
                 GList *fsList;
                 FreqSpec *subFS;
                 int weekMult, dayOfWeek;
@@ -353,8 +342,12 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
         break;
         case UIFREQ_WEEKLY:
         {
+                const char * str;
                 int weeklyMult = -1;
                 int dayOfWeek;
+                GtkWidget *o;
+                FreqSpec *subFS;
+                GList *list;
 
                 for ( list = xaccFreqSpecCompositeGet( fs );
                       list; list = g_list_next(list) ) {
@@ -412,8 +405,12 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
                 break;
         case UIFREQ_SEMI_MONTHLY:
         {
+                GtkWidget *o;
+                GList *list;
                 int monthlyMult;
+                FreqSpec *subFS;
                 int firstDayOfMonth, secondDayOfMonth, monthOffset;
+
                 list = xaccFreqSpecCompositeGet( fs );
                 /*  mult */
                 o = glade_xml_get_widget( gf->gxml, "semimonthly_spin" );
@@ -442,7 +439,9 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
         break;
         case UIFREQ_MONTHLY:
         {
+                GtkWidget *o;
                 int monthlyMult, dayOfMonth, monthOffset;
+
                 if ( xaccFreqSpecGetMonthly( fs, &monthlyMult,
                                              &dayOfMonth, &monthOffset ) < 0 ) {
                         PERR( "Inappropriate FreqSpec type "
@@ -525,6 +524,7 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
         break;
         case UIFREQ_YEARLY:
         {
+                GtkWidget *o;
                 int monthlyMult, dayOfMonth, monthOffset;
 
                 if ( xaccFreqSpecGetMonthly( fs, &monthlyMult,
@@ -543,8 +543,6 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
                 o = glade_xml_get_widget( gf->gxml, "yearly_spin" );
                 gtk_spin_button_set_value( GTK_SPIN_BUTTON(o),
                                            (int)rint(floor(monthlyMult / 12)) );
-                tmpTT = gnc_date_edit_get_date( gf->startDate );
-                tmpTm = localtime( &tmpTT );
                 o = glade_xml_get_widget( gf->gxml, "yearly_month" );
                 gtk_option_menu_set_history( GTK_OPTION_MENU(o), monthOffset );
                 o = glade_xml_get_widget( gf->gxml, "yearly_day" );
@@ -557,52 +555,121 @@ gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *startDate )
                 break;
         }
 
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
+}
+
+static void
+gnc_frequency_setup_default( GNCFrequency *gf, FreqSpec *fs, GDate *date )
+{
+   time_t secs;
+
+   /* If no freq-spec, then set the widget to blank */
+   if (NULL == fs)
+   {
+      UIFreqType uift = UIFREQ_NONE;
+      int i, page;
+
+      page = -1;
+      for ( i=0; i < UIFREQ_NUM_UI_FREQSPECS+1; i++ ) 
+      {
+         if ( PAGES[i].uiFTVal == uift ) 
+         {
+             page = PAGES[i].idx;
+             break;
+         }
+      }
+      g_assert( page != -1 );
+   
+      gtk_notebook_set_current_page( gf->nb, page );
+      gtk_option_menu_set_history( gf->freqOpt, page );
+   }
+
+   /* Setup the start date */
+   if (!date ||  ! g_date_valid(date) ) 
+   {
+      secs = time(NULL);
+   } 
+   else 
+   {
+      struct tm stm;
+      g_date_to_struct_tm( date, &stm);
+      secs = mktime (&stm);
+   }
+ 
+   do_frequency_setup(gf, fs, &secs);
 }
 
 void
-gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
+gnc_frequency_setup( GNCFrequency *gf, FreqSpec *fs, GDate *date )
+{
+   time_t secs;
+
+   if (!gf) return;
+
+   /* Setup the start date */
+   if (!date ||  ! g_date_valid(date) ) 
+   {
+      do_frequency_setup(gf, fs, NULL);
+   } 
+   else 
+   {
+      struct tm stm;
+      g_date_to_struct_tm( date, &stm);
+      secs = mktime (&stm);
+      do_frequency_setup(gf, fs, &secs);
+   }
+}
+
+GtkWidget *
+gnc_frequency_new( FreqSpec *fs, GDate *date )
+{
+        GNCFrequency  *toRet;
+        toRet = g_object_new( gnc_frequency_get_type(), NULL );
+        gnc_frequency_setup_default( toRet, fs, date );
+        return GTK_WIDGET(toRet);
+}
+
+void
+gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outDate )
 {
         gint page;
-        struct tm *tmpTm;
         gint day;
         GtkWidget *o;
         UIFreqType uift;
         FreqSpec *tmpFS;
         gint tmpInt;
         int i;
-        GDate *gd;
-        GDate *gd2;
+        GDate gd;
         time_t tmpTimeT;
 
-        /* get the current tab */
-        page = gtk_notebook_get_current_page( gf->nb );
-        /* save into UIFreqSpec */
+        tmpTimeT = gnc_date_edit_get_date( gf->startDate );
+        if ( NULL != outDate ) 
+        {
+                g_date_set_time_t( outDate, tmpTimeT );
+        }
 
-        /* We're going to be creating/destroying FreqSpecs, which will cause GUI
-           refreshes. :( */
+        if (NULL == fs) return;
+
+        /* Get the current tab */
+        page = gtk_notebook_get_current_page( gf->nb );
+
+        /* We're going to be creating/destroying FreqSpecs, 
+         * which will cause GUI refreshes. :( */
         gnc_suspend_gui_refresh();
 
-        tmpTimeT = gnc_date_edit_get_date( gf->startDate );
-        gd = g_date_new();
-        g_date_set_time( gd, tmpTimeT );
-        if ( outStartDate != NULL ) {
-                g_date_set_time( outStartDate, tmpTimeT );
-        }
+        g_date_clear (&gd, 1);
+        g_date_set_time_t( &gd, tmpTimeT );
+
         /*uift = xaccFreqSpecGetUIType( fs );*/
         uift = PAGES[page].uiFTVal;
 
-        /* based on value, parse widget values into FreqSpec */
+        /* Based on value, parse widget values into FreqSpec */
         switch ( uift ) {
         case UIFREQ_NONE:
-                xaccFreqSpecSetNone( fs );
-                xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
+                /* hmmm... shouldn't really be allowed. */
                 break;
         case UIFREQ_ONCE:
-                xaccFreqSpecSetOnceDate( fs, gd );
                 xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
                 break;
         case UIFREQ_DAILY:
                 o = glade_xml_get_widget( gf->gxml, "daily_spin" );
@@ -611,9 +678,8 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
                         gint foo;
 
                         foo = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON(o) );
-                        xaccFreqSpecSetDaily( fs, gd, foo );
+                        xaccFreqSpecSetDaily( fs, &gd, foo );
                         xaccFreqSpecSetUIType( fs, uift );
-                        g_date_free( gd );
                 }
                 break;
         case UIFREQ_DAILY_MF:
@@ -625,26 +691,26 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
                 /*  support selecting weeks, returning the Sunday selected. */
                 /*  Normalize to sunday. */
                 {
-                        tmpTm = g_new0( struct tm, 1 );
-                        g_date_to_struct_tm( gd, tmpTm );
+                        struct tm stm;
+                        g_date_to_struct_tm( &gd, &stm );
                         /*  month-day += (week-day - current-week-day ) % 7 */
                         /*  week-day <- 0 */
-                        tmpTm->tm_mday -= ( tmpTm->tm_wday ) % 7;
-                        g_date_set_time( gd, mktime( tmpTm ) );
-                        g_free( tmpTm );
+                        stm.tm_mday -= ( stm.tm_wday ) % 7;
+                        g_date_set_time_t( &gd, mktime(&stm) );
                 }
 
                 /*  1 == "mon", 5 == "fri" */
                 for ( i=1; i<6; i++ ) {
-                        g_date_add_days( gd, 1 );
+                        g_date_add_days( &gd, 1 );
                         tmpFS = xaccFreqSpecMalloc(gnc_get_current_book ());
-                        xaccFreqSpecSetWeekly( tmpFS, gd, tmpInt );
+                        xaccFreqSpecSetWeekly( tmpFS, &gd, tmpInt );
                         xaccFreqSpecCompositeAdd( fs, tmpFS );
                 }
-
-                g_date_free( gd );
                 break;
         case UIFREQ_WEEKLY:
+        {
+                struct tm stm;
+                GDate gd2;
                 xaccFreqSpecSetComposite( fs );
                 xaccFreqSpecSetUIType( fs, uift );
                 o = glade_xml_get_widget( gf->gxml, "weekly_spin" );
@@ -652,10 +718,9 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
 
                 /*  assume we have a good calendar that allows week selection. */
                 /*  for-now hack: normalize to Sunday. */
-                tmpTm = g_new0( struct tm, 1 );
-                g_date_to_struct_tm( gd, tmpTm );
-                tmpTm->tm_mday -= tmpTm->tm_wday % 7;
-                g_date_set_time( gd, mktime( tmpTm ) );
+                g_date_to_struct_tm( &gd, &stm);
+                stm.tm_mday -= stm.tm_wday % 7;
+                g_date_set_time_t( &gd, mktime(&stm) );
 
                 /*  now, go through the check boxes and add composites based on that date. */
                 for ( i=0; CHECKBOX_NAMES[i]!=NULL; i++ ) {
@@ -666,25 +731,24 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
                                         (gnc_get_current_book ());
                                 xaccFreqSpecSetUIType( tmpFS, uift );
 
-                                gd2 = g_date_new();
-                                *gd2 = *gd;
+                                g_date_clear (&gd2, 1);
+                                gd2 = gd;
                                 /*  Add 'i' days off of Sunday... */
-                                g_date_add_days( gd2, i );
-                                xaccFreqSpecSetWeekly( tmpFS, gd2, tmpInt );
-                                g_date_free( gd2 );
+                                g_date_add_days( &gd2, i );
+                                xaccFreqSpecSetWeekly( tmpFS, &gd2, tmpInt );
                                 xaccFreqSpecCompositeAdd( fs, tmpFS );
                         }
                 }
-                g_date_free( gd );
-                g_free( tmpTm );
                 break;
+        }
         case UIFREQ_BI_WEEKLY:
                 xaccFreqSpecSetUIType( fs, uift );
                 o = glade_xml_get_widget( gf->gxml, "biweekly_cal" );
-                xaccFreqSpecSetWeekly( fs, gd, 2 );
-                g_date_free( gd );
+                xaccFreqSpecSetWeekly( fs, &gd, 2 );
                 break;
         case UIFREQ_SEMI_MONTHLY:
+        {
+                struct tm stm;
                 /* FIXME: this is b0rken date calculation for mday>28 */
                 xaccFreqSpecSetComposite( fs );
                 xaccFreqSpecSetUIType( fs, uift );
@@ -695,78 +759,67 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
                 o = glade_xml_get_widget( gf->gxml, "semimonthly_first" );
                 day = gnc_option_menu_get_active( GTK_WIDGET(o) )+1;
                 tmpFS = xaccFreqSpecMalloc(gnc_get_current_book ());
-                tmpTm = g_new0( struct tm, 1 );
-                g_date_to_struct_tm( gd, tmpTm );
-                if ( day >= tmpTm->tm_mday ) {
+                g_date_to_struct_tm( &gd, &stm);
+                if ( day >= stm.tm_mday ) {
                         /* next month */
-                        tmpTm->tm_mon += 1;
+                        stm.tm_mon += 1;
                 }
                 /* else, this month */
-                tmpTm->tm_mday = day;
-                g_date_set_time( gd, mktime( tmpTm ) );
-                xaccFreqSpecSetMonthly( tmpFS, gd, tmpInt );
-                g_date_free( gd );
-                g_free( tmpTm );
+                stm.tm_mday = day;
+                g_date_set_time_t( &gd, mktime( &stm) );
+                xaccFreqSpecSetMonthly( tmpFS, &gd, tmpInt );
                 xaccFreqSpecCompositeAdd( fs, tmpFS );
 
                 o = glade_xml_get_widget( gf->gxml, "semimonthly_second" );
                 day = gnc_option_menu_get_active( GTK_WIDGET(o) )+1;
                 tmpFS = xaccFreqSpecMalloc(gnc_get_current_book ());
                 tmpTimeT = gnc_date_edit_get_date( gf->startDate );
-                gd = g_date_new();
-                g_date_set_time( gd, tmpTimeT );
-                tmpTm = g_new0( struct tm, 1 );
-                g_date_to_struct_tm( gd, tmpTm );
-                if ( day >= tmpTm->tm_mday ) {
+                g_date_set_time_t( &gd, tmpTimeT );
+                g_date_to_struct_tm( &gd, &stm);
+                if ( day >= stm.tm_mday ) {
                         /* next month */
-                        tmpTm->tm_mon += 1;
+                        stm.tm_mon += 1;
                 }
                 /* else, this month */
-                tmpTm->tm_mday = day;
-                g_date_set_time( gd, mktime( tmpTm ) );
-                xaccFreqSpecSetMonthly( tmpFS, gd, tmpInt );
-                g_date_free( gd );
-                g_free( tmpTm );
+                stm.tm_mday = day;
+                g_date_set_time_t( &gd, mktime( &stm ) );
+                xaccFreqSpecSetMonthly( tmpFS, &gd, tmpInt );
                 xaccFreqSpecCompositeAdd( fs, tmpFS );
 
                 break;
+        }
         case UIFREQ_MONTHLY:
+        {
+                struct tm stm;
                 o = glade_xml_get_widget( gf->gxml, "monthly_spin" );
                 tmpInt = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(o));
-                tmpTm = g_new0( struct tm, 1 );
-                g_date_to_struct_tm( gd, tmpTm );
+                g_date_to_struct_tm( &gd, &stm);
 
                 o = glade_xml_get_widget( gf->gxml, "monthly_day" );
                 day = gnc_option_menu_get_active( GTK_WIDGET(o) ) + 1;
-                tmpTm->tm_mday = day;
-                g_date_set_time( gd, mktime( tmpTm ) );
-                xaccFreqSpecSetMonthly( fs, gd, tmpInt );
+                stm.tm_mday = day;
+                g_date_set_time_t( &gd, mktime( &stm ) );
+                xaccFreqSpecSetMonthly( fs, &gd, tmpInt );
                 xaccFreqSpecSetUIType( fs, uift );
-
-                g_free( tmpTm );
-                g_date_free( gd );
                 break;
+        }
         case UIFREQ_QUARTERLY:
-                xaccFreqSpecSetMonthly( fs, gd, 3 );
+                xaccFreqSpecSetMonthly( fs, &gd, 3 );
                 xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
                 break;
         case UIFREQ_TRI_ANUALLY:
-                xaccFreqSpecSetMonthly( fs, gd, 4 );
+                xaccFreqSpecSetMonthly( fs, &gd, 4 );
                 xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
                 break;
         case UIFREQ_SEMI_YEARLY:
-                xaccFreqSpecSetMonthly( fs, gd, 6 );
+                xaccFreqSpecSetMonthly( fs, &gd, 6 );
                 xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
                 break;
         case UIFREQ_YEARLY:
                 o = glade_xml_get_widget( gf->gxml, "yearly_spin" );
                 tmpInt = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON(o) );
-                xaccFreqSpecSetMonthly( fs, gd, tmpInt * 12 );
+                xaccFreqSpecSetMonthly( fs, &gd, tmpInt * 12 );
                 xaccFreqSpecSetUIType( fs, uift );
-                g_date_free( gd );
                 break;
         default:
                 PERR( "Unknown UIFreqType %d [%d, %s]\n",
@@ -779,7 +832,7 @@ gnc_frequency_save_state( GNCFrequency *gf, FreqSpec *fs, GDate *outStartDate )
 static void
 spin_changed_helper( GtkAdjustment *adj, gpointer d )
 {
-        gtk_signal_emit_by_name( GTK_OBJECT(GNC_FREQUENCY(d)), "changed", NULL );
+        g_signal_emit_by_name( GNC_FREQUENCY(d), "changed" );
 }
 
 static void
@@ -788,7 +841,7 @@ weekly_days_changed( GtkButton *b, gpointer d )
         GNCFrequency *gf;
 
         gf = GNC_FREQUENCY(d);
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
 
 static void
@@ -817,7 +870,7 @@ monthly_sel_changed( GtkButton *b, gpointer d )
         tmptt = mktime( tmptm );
         gnc_date_edit_set_time( gf->startDate, tmptt );
 
-        gtk_signal_emit_by_name( GTK_OBJECT(d), "changed", NULL );
+        g_signal_emit_by_name( d, "changed" );
 }
 
 static void
@@ -850,7 +903,7 @@ semimonthly_sel_changed( GtkButton *b, gpointer d )
         tmptt = mktime( tmptm );
         gnc_date_edit_set_time( gf->startDate, tmptt );
 
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
 
 static void
@@ -905,7 +958,7 @@ year_range_sels_changed( GNCFrequency *gf,
         tmpTT = mktime( tmpTm );
         gnc_date_edit_set_time( gf->startDate, tmpTT );
 
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
 
 static void
@@ -938,7 +991,7 @@ yearly_sel_changed( GtkButton *b, gpointer d )
         tmptt = mktime( tmptm );
         gnc_date_edit_set_time( gf->startDate, tmptt );
 
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
 
 static inline guint32 min( guint32 a, guint32 b )
@@ -963,7 +1016,7 @@ freq_option_value_changed( GtkMenuShell *b, gpointer d )
 
         /* Set the new page. */
         optIdx = gnc_option_menu_get_active( GTK_WIDGET(((GNCFrequency*)d)->freqOpt) );
-        gtk_notebook_set_page( ((GNCFrequency*)d)->nb, optIdx );
+        gtk_notebook_set_current_page( ((GNCFrequency*)d)->nb, optIdx );
 
         /* setup initial values for new page, as possible. */
         uift = PAGES[optIdx].uiFTVal;
@@ -1024,7 +1077,7 @@ freq_option_value_changed( GtkMenuShell *b, gpointer d )
                 /* nuttin can be done, for whatever reason. */
                 break;
         }
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
 
 static void
@@ -1125,5 +1178,28 @@ start_date_changed( GNCDateEdit *gde, gpointer d )
                 PERR( "unknown uift value %d\n", uift );
                 break;
         }
-        gtk_signal_emit_by_name( GTK_OBJECT(gf), "changed", NULL );
+        g_signal_emit_by_name( gf, "changed" );
 }
+
+/* ================================================================= */
+/* Relabel some of the labels */
+
+void 
+gnc_frequency_set_frequency_label_text (GNCFrequency *gf, const gchar *txt)
+{
+   GtkLabel *lbl;
+	if (!gf || !txt) return;
+   lbl = GTK_LABEL (glade_xml_get_widget (gf->gxml, "freq label"));
+   gtk_label_set_text (lbl, txt);
+}
+
+void 
+gnc_frequency_set_date_label_text (GNCFrequency *gf, const gchar *txt)
+{
+   GtkLabel *lbl;
+	if (!gf || !txt) return;
+   lbl = GTK_LABEL (glade_xml_get_widget (gf->gxml, "startdate label"));
+   gtk_label_set_text (lbl, txt);
+}
+
+/* ========================= END OF FILE =========================== */
