@@ -18,25 +18,28 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  ********************************************************************/
 
 #include "config.h"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include "glib-compat.h"
 
+#include "gnc-engine.h"
+#include "SX-book.h"
+#include "SX-book-p.h"
 #include "SX-ttinfo.h"
 #include "SchedXaction.h"
 #include "gnc-component-manager.h"
 #include "dialog-scheduledxaction.h"
 #include "dialog-sx-from-trans.h"
 #include "dialog-utils.h"
-#include "global-options.h"
-#include "gnc-book.h"
-#include "gnc-book-p.h"
 #include "gnc-date-edit.h"
-#include "gnc-engine-util.h"
+#include "qof.h"
+#include "gnc-gconf-utils.h"
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "gnc-dense-cal.h"
@@ -53,27 +56,24 @@
 #define SXFTD_NAME_ENTRY "name_entry"
 #define SXFTD_N_OCCURRENCES_ENTRY "n_occurrences_entry"
 #define SXFTD_FREQ_OPTION_MENU "freq_option_menu"
-//#define SXFTD_END_DATE_EDIT "end_date_edit"
+/* #define SXFTD_END_DATE_EDIT "end_date_edit" */
 #define SXFTD_START_DATE_EDIT "start_date_edit"
 #define SXFTD_EX_CAL_FRAME "ex_cal_frame"
 #define SXFTD_END_DATE_BOX "end_date_hbox"
 
-#define SX_OPT_STR "Scheduled Transactions"
-
 #define SXFTD_ERRNO_UNBALANCED_XACTION 3
 #define SXFTD_ERRNO_OPEN_XACTION -3
 
 #define SXFTD_EXCAL_NUM_MONTHS 4
 #define SXFTD_EXCAL_MONTHS_PER_COL 4
 
-static short module = MOD_SX;
+#define SXFTD_RESPONSE_ADVANCED 100 /* 'Advanced' button response code */
 
-/** start_date_edit, end_date_edit, param_table, end_date_hbox */
+static QofLogModule log_module = GNC_MOD_SX;
 
-static void sxftd_ok_clicked(GtkWidget *w, gpointer user_data);
 static void sxftd_freq_option_changed( GtkWidget *w, gpointer user_data );
-static void sxftd_advanced_clicked(GtkWidget *w, gpointer user_data);
-static void sxftd_cancel_clicked(GtkWidget *w, gpointer user_data);
+static void gnc_sx_trans_window_response_cb(GtkDialog *dialog, gint response, gpointer data);
+
 static void sxftd_destroy( GtkWidget *w, gpointer user_data );
 
 typedef enum { NEVER_END, END_ON_DATE, END_AFTER_N_OCCS, BAD_END } endType;
@@ -113,7 +113,7 @@ typedef struct
 } getEndTuple;
 
 static void sxftd_update_example_cal( SXFromTransInfo *sxfti );
-static void sxftd_update_excal_adapt( GtkObject *o, gpointer ud );
+static void sxftd_update_excal_adapt( GObject *o, gpointer ud );
 
 /* Stolen from jsled - nice and neat, actually (if a little light on 
  * for typechecking, but we'll be careful) . . . 
@@ -125,6 +125,11 @@ typedef struct
   void (*handlerFn)();
 } widgetSignalHandlerTuple;
 
+
+static void sxftd_ok_clicked(SXFromTransInfo *sxfti);
+static void sxftd_advanced_clicked(SXFromTransInfo *sxfti);
+
+
 static void
 sxfti_attach_callbacks(SXFromTransInfo *sxfti)
 {
@@ -138,10 +143,6 @@ sxfti_attach_callbacks(SXFromTransInfo *sxfti)
       { SXFTD_N_OCCURRENCES_BUTTON, "clicked",      sxftd_update_excal_adapt },
       { SXFTD_N_OCCURRENCES_ENTRY,  "changed",      sxftd_update_excal_adapt },
 
-      { SXFTD_OK_BUTTON,       "clicked", sxftd_ok_clicked },
-      { SXFTD_ADVANCED_BUTTON, "clicked", sxftd_advanced_clicked },
-      { SXFTD_CANCEL_BUTTON,   "clicked", sxftd_cancel_clicked },
-
       { NULL,                  NULL,      NULL }
     };
   
@@ -152,10 +153,14 @@ sxfti_attach_callbacks(SXFromTransInfo *sxfti)
   {
     w = glade_xml_get_widget(sxfti->gxml, callbacks[i].name);
     
-    gtk_signal_connect( GTK_OBJECT(w), callbacks[i].signal, 
-			GTK_SIGNAL_FUNC(callbacks[i].handlerFn),
-			sxfti );
+    g_signal_connect (GTK_OBJECT(w), callbacks[i].signal, 
+		      G_CALLBACK(callbacks[i].handlerFn),
+		      sxfti );
   }
+
+  g_signal_connect (G_OBJECT(sxfti->dialog), "response",
+                    G_CALLBACK (gnc_sx_trans_window_response_cb), 
+                    sxfti);
 }
   
 
@@ -166,28 +171,27 @@ sxftd_get_end_info(SXFromTransInfo *sxfti)
   GtkWidget *w;
 
   retval.type = BAD_END;
+  g_date_clear( &(retval.end_date), 1 );
+  retval.n_occurrences = 0;
 
   w = glade_xml_get_widget(sxfti->gxml, SXFTD_NEVER_END_BUTTON);
-  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w)))
-  {
+  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w))) {
     retval.type = NEVER_END;
     return retval;
   }
   
   w = glade_xml_get_widget(sxfti->gxml, SXFTD_END_ON_DATE_BUTTON);
-  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w)))
-  {
+  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w))) {
     time_t end_tt;
     retval.type = END_ON_DATE;
     g_date_clear( &(retval.end_date), 1 );
     end_tt = gnc_date_edit_get_date(sxfti->endDateGDE);
-    g_date_set_time( &(retval.end_date), end_tt);
+    g_date_set_time_t( &(retval.end_date), end_tt);
     return retval;
   }
     
   w = glade_xml_get_widget(sxfti->gxml, SXFTD_N_OCCURRENCES_BUTTON);
-  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w) ))
-  {
+  if(gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w) )) {
     gchar *text, *endptr;
     guint n_occs;
     w = glade_xml_get_widget(sxfti->gxml, SXFTD_N_OCCURRENCES_ENTRY);
@@ -197,9 +201,10 @@ sxftd_get_end_info(SXFromTransInfo *sxfti)
     if ( !endptr ) {
       n_occs = -1;
     }
+
     g_free(text);
-    if(n_occs > 0)
-    {
+
+    if(n_occs > 0) {
       retval.type = END_AFTER_N_OCCS;
       retval.n_occurrences = n_occs;
       return retval;
@@ -230,8 +235,7 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
   gnc_ttinfo_set_num(tti, xaccTransGetNum(tr));
   gnc_ttinfo_set_currency(tti, xaccTransGetCurrency(tr));
 
-  for(splits = xaccTransGetSplitList(tr); splits; splits = splits->next)
-  {
+  for(splits = xaccTransGetSplitList(tr); splits; splits = splits->next) {
     sp = splits->data;
     ttsi = gnc_ttsplitinfo_malloc();
     gnc_ttsplitinfo_set_action(ttsi, xaccSplitGetAction(sp));
@@ -241,14 +245,12 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
     runningBalance = gnc_numeric_add( runningBalance, split_value,
                                       100, (GNC_DENOM_AUTO | GNC_DENOM_LCD) );
 
-    if(gnc_numeric_positive_p(split_value))
-    {
+    if(gnc_numeric_positive_p(split_value)) {
             tmpStr = xaccPrintAmount( split_value,
                                       gnc_default_print_info(FALSE) );
             gnc_ttsplitinfo_set_debit_formula( ttsi, tmpStr );
     }
-    else
-    {
+    else {
             /* Negate the numeric so it prints w/o the sign at the front. */
             tmpStr = xaccPrintAmount( gnc_numeric_neg( split_value ),
                                       gnc_default_print_info(FALSE) );
@@ -262,13 +264,13 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
   }
 
   if ( ! gnc_numeric_zero_p( runningBalance )
-          && !gnc_verify_dialog_parented( sxfti->dialog, FALSE,
-                                          "%s",
-                                          _("The Scheduled Transaction Editor "
-                                            "cannot automatically\nbalance "
-                                            "this transaction. "
-                                            "Should it still be "
-                                            "entered?") ) ) {
+          && !gnc_verify_dialog( (gncUIWidget)sxfti->dialog,
+                                 FALSE, "%s",
+                                 _("The Scheduled Transaction Editor "
+                                   "cannot automatically balance "
+                                   "this transaction. "
+                                   "Should it still be "
+                                   "entered?") ) ) {
         return SXFTD_ERRNO_UNBALANCED_XACTION;
   }
 
@@ -315,7 +317,7 @@ sxftd_update_fs( SXFromTransInfo *sxfti, GDate *date, FreqSpec *fs )
     tmpfs = xaccFreqSpecMalloc( gnc_get_current_book() );
     xaccFreqSpecSetComposite( fs );
     xaccFreqSpecSetWeekly( tmpfs, date, 2 );
-    xaccFreqSpecSetUIType( fs, UIFREQ_WEEKLY );
+    xaccFreqSpecSetUIType( fs, UIFREQ_BI_WEEKLY );
     xaccFreqSpecCompositeAdd( fs, tmpfs );
     break;
 
@@ -395,9 +397,9 @@ sxftd_init( SXFromTransInfo *sxfti )
                       (GTK_EXPAND | GTK_FILL),
                       GTK_FILL,
                       0, 0 );
-    gtk_signal_connect( GTK_OBJECT( sxfti->startDateGDE ), "date-changed",
-                        GTK_SIGNAL_FUNC( sxftd_update_excal_adapt ),
-                        sxfti );
+    g_signal_connect( sxfti->startDateGDE, "date-changed",
+                      G_CALLBACK( sxftd_update_excal_adapt ),
+                      sxfti );
   }
   {
     GtkWidget *endDateBox = glade_xml_get_widget( sxfti->gxml,
@@ -408,9 +410,9 @@ sxftd_init( SXFromTransInfo *sxfti )
     gtk_box_pack_start( GTK_BOX( endDateBox ),
                         GTK_WIDGET( sxfti->endDateGDE ),
                         FALSE, TRUE, 0 );
-    gtk_signal_connect( GTK_OBJECT( sxfti->endDateGDE ), "date-changed",
-                        GTK_SIGNAL_FUNC( sxftd_update_excal_adapt ),
-                        sxfti );
+    g_signal_connect( sxfti->endDateGDE, "date-changed",
+                      G_CALLBACK( sxftd_update_excal_adapt ),
+                      sxfti );
   }
 
   /* Get the name from the transaction, try that as the initial SX name. */
@@ -420,7 +422,7 @@ sxftd_init( SXFromTransInfo *sxfti )
   /* Setup the initial start date for user display/confirmation */
   /* compute good initial date. */
   start_tt = xaccTransGetDate( sxfti->trans );
-  g_date_set_time( &date, start_tt );
+  g_date_set_time_t( &date, start_tt );
   fs = xaccFreqSpecMalloc( gnc_get_current_book() );
   sxftd_update_fs( sxfti, &date, fs );
   xaccFreqSpecGetNextInstance( fs, &date, &nextDate );
@@ -440,12 +442,13 @@ sxftd_init( SXFromTransInfo *sxfti )
 			   SXFTD_FREQ_OPTION_MENU);
   gnc_option_menu_init(w);
   w = gtk_option_menu_get_menu( GTK_OPTION_MENU(w) );
-  gtk_signal_connect( GTK_OBJECT(w), "selection-done",
-                      GTK_SIGNAL_FUNC(sxftd_freq_option_changed),
-                      sxfti );
-  gtk_signal_connect( GTK_OBJECT(w), "destroy",
-                      GTK_SIGNAL_FUNC(sxftd_destroy),
-                      sxfti );
+  g_signal_connect( GTK_OBJECT(w), "selection-done",
+                    G_CALLBACK(sxftd_freq_option_changed),
+                    sxfti );
+
+  g_signal_connect( GTK_OBJECT(w), "destroy",
+                    G_CALLBACK(sxftd_destroy),
+                    sxfti );
 
   sxftd_update_example_cal( sxfti );
   
@@ -472,12 +475,11 @@ sxftd_compute_sx(SXFromTransInfo *sxfti)
   xaccSchedXactionSetName(sx, name);
   g_free(name);
 
-  g_date_set_time( &date, gnc_date_edit_get_date( sxfti->startDateGDE ) );
+  g_date_set_time_t( &date, gnc_date_edit_get_date( sxfti->startDateGDE ) );
  
   fs = xaccFreqSpecMalloc(gnc_get_current_book ());
   sxftd_update_fs( sxfti, &date, fs );
-  if (sxftd_errno == 0)
-  {
+  if (sxftd_errno == 0) {
     xaccSchedXactionSetFreqSpec( sx, fs);
     xaccSchedXactionSetStartDate( sx, &date );
   }
@@ -511,72 +513,57 @@ sxftd_compute_sx(SXFromTransInfo *sxfti)
     gint daysInAdvance;
 
     autoCreateState =
-      gnc_lookup_boolean_option( SX_OPT_STR,
-                                 "Auto-Create new Scheduled "
-                                 "Transactions by default", FALSE );
+      gnc_gconf_get_bool( SXED_GCONF_SECTION, KEY_CREATE_AUTO, NULL );
     notifyState =
-      gnc_lookup_boolean_option( SX_OPT_STR,
-                                 "Notify on new, auto-created "
-                                 "Scheduled Transactions", FALSE );
+      gnc_gconf_get_bool( SXED_GCONF_SECTION, KEY_NOTIFY, NULL );
     xaccSchedXactionSetAutoCreate( sx,
                                    autoCreateState,
                                    (autoCreateState & notifyState) );
     
     daysInAdvance =
-      (int)gnc_lookup_number_option( SX_OPT_STR,
-                                     "Default number of days in "
-                                     "advance to create", 0 );
+      gnc_gconf_get_float( SXED_GCONF_SECTION, KEY_CREATE_DAYS, NULL );
     xaccSchedXactionSetAdvanceCreation( sx, daysInAdvance );
 
     daysInAdvance =
-      (int)gnc_lookup_number_option( SX_OPT_STR,
-                                     "Default number of days in "
-                                     "advance to remind", 0 );
+      gnc_gconf_get_float( SXED_GCONF_SECTION, KEY_REMIND_DAYS, NULL );
     xaccSchedXactionSetAdvanceReminder( sx, daysInAdvance );
   }
 
-  if ( sxftd_add_template_trans( sxfti ) != 0 )
-  {
+  if ( sxftd_add_template_trans( sxfti ) != 0 ) {
           sxftd_errno = SXFTD_ERRNO_UNBALANCED_XACTION;
   }
 
   return sxftd_errno;
 }
 
-static
-void
+static void
 sxftd_close(SXFromTransInfo *sxfti, gboolean delete_sx)
 {
-  if ( sxfti->sx && delete_sx )
-  {
+  if ( sxfti->sx && delete_sx ) {
     xaccSchedXactionFree(sxfti->sx);
   }
   sxfti->sx = NULL;
 
-  gnome_dialog_close( GNOME_DIALOG(sxfti->dialog));
-
-  return;
+  gtk_widget_destroy (GTK_WIDGET (sxfti->dialog));
 }
 
 static void
-sxftd_ok_clicked(GtkWidget *w, gpointer user_data)
+sxftd_ok_clicked(SXFromTransInfo *sxfti)
 {
-  SXFromTransInfo *sxfti = user_data;
-  GNCBook *book;
+  QofBook *book;
   GList *sx_list;
   guint sx_error = sxftd_compute_sx(sxfti);
 
   if (sx_error != 0
-      && sx_error != SXFTD_ERRNO_UNBALANCED_XACTION)
-  {
+      && sx_error != SXFTD_ERRNO_UNBALANCED_XACTION) {
     PERR( "Error in sxftd_compute_sx after ok_clicked [%d]", sx_error );
   }
-  else
-  {
+  else {
     SchedXactionDialog *sxd;
 
     if ( sx_error == SXFTD_ERRNO_UNBALANCED_XACTION ) {
-            gnc_error_dialog( _( "The Scheduled Transaction is unbalanced.\n"
+            gnc_error_dialog( gnc_ui_get_toplevel(), 
+                              _( "The Scheduled Transaction is unbalanced. "
                                  "You are strongly encouraged to correct this situation." ) );
     }
     book = gnc_get_current_book ();
@@ -610,7 +597,7 @@ sxftd_freq_option_changed( GtkWidget *w, gpointer user_data )
   FreqSpec *fs;
 
   tmp_tt = xaccTransGetDate( sxfti->trans );
-  g_date_set_time( &date, tmp_tt );
+  g_date_set_time_t( &date, tmp_tt );
   
   fs = xaccFreqSpecMalloc( gnc_get_current_book() );
   sxftd_update_fs( sxfti, &date, fs );
@@ -627,19 +614,12 @@ sxftd_freq_option_changed( GtkWidget *w, gpointer user_data )
 }
 
 static void
-sxftd_cancel_clicked(GtkWidget *w, gpointer user_data)
+sxftd_advanced_clicked(SXFromTransInfo *sxfti)
 {
-  SXFromTransInfo *sxfti = user_data;
-  sxftd_close(sxfti, TRUE);
-}
-
-static void
-sxftd_advanced_clicked(GtkWidget *w, gpointer user_data)
-{
-  SXFromTransInfo *sxfti = user_data;
   guint sx_error = sxftd_compute_sx(sxfti);
   SchedXactionDialog *adv_dlg;
   SchedXactionEditorDialog *adv_edit_dlg;
+  GMainContext *context;
 
   if ( sx_error != 0
        && sx_error != SXFTD_ERRNO_UNBALANCED_XACTION )
@@ -651,7 +631,8 @@ sxftd_advanced_clicked(GtkWidget *w, gpointer user_data)
   }
   gtk_widget_hide( sxfti->dialog );
   /* force a gui update. */
-  while (g_main_iteration(FALSE));
+  context = g_main_context_default();
+  while (g_main_context_iteration(context, FALSE));
 
   adv_dlg = gnc_ui_scheduled_xaction_dialog_create();
   adv_edit_dlg =
@@ -663,45 +644,7 @@ sxftd_advanced_clicked(GtkWidget *w, gpointer user_data)
   sxftd_close(sxfti, FALSE);
 }
 
-void
-gnc_sx_create_from_trans( Transaction *trans )
-{
-  int errno;
-  SXFromTransInfo *sxfti = g_new0( SXFromTransInfo, 1);
-
-  sxfti->gxml = gnc_glade_xml_new(SX_GLADE_FILE,
-				  SXFTD_DIALOG_GLADE_NAME);
-  
-  sxfti->dialog = glade_xml_get_widget(sxfti->gxml,
-				       SXFTD_DIALOG_GLADE_NAME);
-
-  sxfti->trans = trans;
-  
-  sxfti->sx = xaccSchedXactionMalloc(gnc_get_current_book ());
-
-  if ( (errno = sxftd_init( sxfti )) < 0 ) {
-          if ( errno == SXFTD_ERRNO_OPEN_XACTION )
-          {
-                  gnc_error_dialog( _( "Cannot create a Scheduled Transaction "
-                                       "from a Transaction currently\n"
-                                       "being edited. Please Enter the "
-                                       "Transaction before Scheduling." ) );
-                  sxftd_close( sxfti, TRUE );
-                  return;
-          }
-          else
-          {
-                  PERR( "Error in sxftd_init: %d", errno );
-          }
-  }
-
-  gtk_widget_show_all(sxfti->dialog);
-
-  return;
-}
-
-static
-void
+static void
 sxftd_destroy( GtkWidget *w, gpointer user_data )
 {
   int i;
@@ -722,12 +665,43 @@ sxftd_destroy( GtkWidget *w, gpointer user_data )
   g_free(sxfti);
 }
 
+
+/**
+ *
+ **/
+static void
+gnc_sx_trans_window_response_cb (GtkDialog *dialog,
+                                gint response,
+                                gpointer data)
+{
+	SXFromTransInfo *sxfti = (SXFromTransInfo *)data;
+
+	ENTER(" dialog %p, response %d, sx %p", dialog, response, sxfti);
+        switch (response) {
+                case GTK_RESPONSE_OK:
+                        DEBUG(" OK");
+			sxftd_ok_clicked(sxfti);
+			break;
+		case SXFTD_RESPONSE_ADVANCED:
+			DEBUG(" ADVANCED");
+			sxftd_advanced_clicked(sxfti);
+			break;
+                case GTK_RESPONSE_CANCEL:
+                default:
+                        DEBUG(" CANCEL");
+			sxftd_close(sxfti, TRUE);
+                        break;
+
+	}
+	LEAVE(" ");
+}
+
+
 /**
  * Update the example calendar; make sure to take into account the end
  * specification.
  **/
-static
-void
+static void
 sxftd_update_example_cal( SXFromTransInfo *sxfti )
 {
   struct tm *tmpTm;
@@ -739,24 +713,27 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
   gchar *name;
   GString *info;
 
-  i = 0;
   fs = xaccFreqSpecMalloc( gnc_get_current_book() );
   get = sxftd_get_end_info( sxfti );
 
   tmp_tt = gnc_date_edit_get_date( sxfti->startDateGDE );
   tmpTm = g_new0( struct tm, 1 );
   *tmpTm = *localtime( &tmp_tt );
-  /* go one day before what's in the box so we can get the correct start
-   * date. */
-  g_date_set_day( &date, tmpTm->tm_mday-1 );
+  g_date_clear(&date, 1);
+  g_date_set_day( &date, tmpTm->tm_mday );
   g_date_set_month( &date, tmpTm->tm_mon+1 );
   g_date_set_year( &date, tmpTm->tm_year+1900 );
   g_free( tmpTm );
 
   sxftd_update_fs( sxfti, &date, fs );
+
+  /* go one day before what's in the box so we can get the correct start
+   * date. */
+  g_date_subtract_days(&date, 1);
   xaccFreqSpecGetNextInstance( fs, &date, &date );
   startDate = date;
 
+  i = 0;
   while ( (i < (SXFTD_EXCAL_NUM_MONTHS * 31))
           && g_date_valid( &date )
           /* Do checking against end restriction. */
@@ -777,9 +754,9 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
   if ( i > 0 ) {
     GtkWidget *w;
     gnc_dense_cal_set_month( sxfti->example_cal,
-                             g_date_month( &startDate ) );
+                             g_date_get_month( &startDate ) );
     gnc_dense_cal_set_year( sxfti->example_cal,
-                            g_date_year( &startDate ) );
+                            g_date_get_year( &startDate ) );
     w = glade_xml_get_widget( sxfti->gxml, SXFTD_NAME_ENTRY );
     name = gtk_editable_get_chars( GTK_EDITABLE(w), 0, -1 );
     info = g_string_sized_new( 16 );
@@ -797,10 +774,52 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
 }
 
 
-static
-void
-sxftd_update_excal_adapt( GtkObject *o, gpointer ud )
+/**
+ * Callback to update the calendar
+ **/
+static void
+sxftd_update_excal_adapt( GObject *o, gpointer ud )
 {
   SXFromTransInfo *sxfti = (SXFromTransInfo*)ud;
   sxftd_update_example_cal( sxfti );
 }
+
+
+/**
+ *
+ **/
+void
+gnc_sx_create_from_trans( Transaction *trans )
+{
+  int errno;
+  SXFromTransInfo *sxfti = g_new0( SXFromTransInfo, 1);
+
+  sxfti->gxml = gnc_glade_xml_new(SX_GLADE_FILE,
+				  SXFTD_DIALOG_GLADE_NAME);
+  
+  sxfti->dialog = glade_xml_get_widget(sxfti->gxml,
+				       SXFTD_DIALOG_GLADE_NAME);
+
+  sxfti->trans = trans;
+  
+  sxfti->sx = xaccSchedXactionMalloc(gnc_get_current_book ());
+
+  if ( (errno = sxftd_init( sxfti )) < 0 ) {
+          if ( errno == SXFTD_ERRNO_OPEN_XACTION )
+          {
+                  gnc_error_dialog( gnc_ui_get_toplevel(),
+                                    _( "Cannot create a Scheduled Transaction "
+                                       "from a Transaction currently "
+                                       "being edited. Please Enter the "
+                                       "Transaction before Scheduling." ) );
+                  sxftd_close( sxfti, TRUE );
+                  return;
+          }
+          else
+          {
+                  PERR( "Error in sxftd_init: %d", errno );
+          }
+  }
+
+  gtk_widget_show_all(GTK_WIDGET(sxfti->dialog));
+}
