@@ -188,7 +188,7 @@ static GtkActionEntry gnc_plugin_page_account_tree_actions [] = {
 	{ "ScrubAction", NULL, N_("Check & Repair A_ccount"), NULL,
 	  N_("Check for and repair unbalanced transactions and orphan splits " "in this account"),
 	  G_CALLBACK (gnc_plugin_page_account_tree_cmd_scrub) },
-	{ "ScrubSubAction", NULL, N_("Check & Repair Su_baccount"), NULL,
+	{ "ScrubSubAction", NULL, N_("Check & Repair Su_baccounts"), NULL,
 	  N_("Check for and repair unbalanced transactions and orphan splits "
              "in this account and its subaccounts"),
 	  G_CALLBACK (gnc_plugin_page_account_tree_cmd_scrub_sub) },
@@ -1095,7 +1095,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
 	GList *acct_list, *ptr;
 
 	xaccAccountBeginEdit (daa);
-	acct_list = xaccGroupGetSubAccounts(children);
+	acct_list = g_list_copy(xaccGroupGetAccountList(children));
 	for (ptr = acct_list; ptr; ptr = g_list_next(ptr))
 	  xaccAccountInsertSubAccount (daa, ptr->data);
 	g_list_free(acct_list);
@@ -1215,7 +1215,8 @@ gnc_plugin_page_account_tree_cmd_scrub (GtkAction *action, GncPluginPageAccountT
 	xaccAccountScrubOrphans (account);
 	xaccAccountScrubImbalance (account);
 
-	xaccAccountScrubLots (account);
+	// XXX: Lots are disabled
+	//xaccAccountScrubLots (account);
 
 	gnc_resume_gui_refresh ();
 }
@@ -1232,7 +1233,8 @@ gnc_plugin_page_account_tree_cmd_scrub_sub (GtkAction *action, GncPluginPageAcco
 	xaccAccountTreeScrubOrphans (account);
 	xaccAccountTreeScrubImbalance (account);
 
-	xaccAccountTreeScrubLots (account);
+	// XXX: Lots are disabled
+	//xaccAccountTreeScrubLots (account);
 
 	gnc_resume_gui_refresh ();
 }
@@ -1247,7 +1249,8 @@ gnc_plugin_page_account_tree_cmd_scrub_all (GtkAction *action, GncPluginPageAcco
 	xaccGroupScrubOrphans (group);
 	xaccGroupScrubImbalance (group);
 
-	xaccGroupScrubLots (group);
+	// XXX: Lots are disabled
+	//xaccGroupScrubLots (group);
 
 	gnc_resume_gui_refresh ();
 }
