@@ -170,10 +170,10 @@ void gnc_split_register_size_allocate (GtkWidget *widget,
 FROM_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 AS_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 
-guint
+GType
 gnc_split_reg_get_type( void )
 {
-  static guint gnc_split_reg_type = 0;
+  static GType gnc_split_reg_type = 0;
 
   if (!gnc_split_reg_type)
     {
@@ -991,7 +991,7 @@ gsr_default_reinit_handler( GNCSplitReg *gsr, gpointer data )
 
   gtk_dialog_add_button(GTK_DIALOG(dialog),
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-  gnc_gtk_dialog_add_button(dialog, N_("_Remove Splits"),
+  gnc_gtk_dialog_add_button(dialog, _("_Remove Splits"),
 			    GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT);
   response = gnc_dialog_run(GTK_DIALOG(dialog), warning);
   gtk_widget_destroy (dialog);
