@@ -13,8 +13,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 \********************************************************************/
 /** @addtogroup Import_Export
     @{ */
@@ -23,33 +23,36 @@
     @brief .log file replay code
     @author Copyright (c) 2003 Benoit Grgoire <bock@step.polymtl.ca>
 */
-#define _GNU_SOURCE
-
 #include "config.h"
 
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/time.h>
-
-#include <glib.h>
 #include <libguile.h>
-#include <gmodule.h>
+#include <errno.h>
 
 #include "Account.h"
 #include "Transaction.h"
 #include "TransactionP.h"
-#include "global-options.h"
+#include "TransLog.h"
+#include "Scrub.h"
 #include "gnc-log-replay.h"
-#include "gnc-file-dialog.h"
-#include "gnc-engine-util.h"
+#include "gnc-file.h"
+#include "qof.h"
 #include "gnc-book.h"
 #include "gnc-ui-util.h"
+#include "gnc-gconf-utils.h"
+#include "gnc-gui-query.h"
 
-#include "dialog-utils.h"
+#define GCONF_SECTION "dialogs/log_replay"
 
-
-/*static short module = MOD_IMPORT;*/
-static short module = MOD_TEST;
+/* NW: If you want a new log_module, just define
+a unique string either in gnc-engine.h or
+locally.*/
+/*static QofLogModule log_module = GNC_MOD_IMPORT;*/
+static QofLogModule log_module = GNC_MOD_TEST;
 
 /* fprintf (trans_log, "mod	guid	time_now	" \
    "date_entered	date_posted	" \
@@ -102,12 +105,6 @@ typedef struct _split_record
  * Entry point
 \********************************************************************/
 
-SCM  scm_gnc_file_log_replay ()
-{
-  gnc_file_log_replay();
-  return SCM_EOL;
-}
-
 static char *olds;
 /* This version of strtok will only match SINGLE occurence of delim,
    returning a 0 length valid string between two consecutive ocurence of delim.
@@ -180,17 +177,17 @@ static split_record interpret_split_record( char *record_line)
     }
   if(strlen(tok_ptr = my_strtok(NULL,"\t"))!=0)
     {  
-      record.log_date = gnc_iso8601_to_timespec_local(tok_ptr);
+      record.log_date = gnc_iso8601_to_timespec_gmt(tok_ptr);
       record.log_date_present=TRUE;
     }
   if(strlen(tok_ptr = my_strtok(NULL,"\t"))!=0)
     {  
-      record.date_entered = gnc_iso8601_to_timespec_local(tok_ptr);
+      record.date_entered = gnc_iso8601_to_timespec_gmt(tok_ptr);
       record.date_entered_present=TRUE;
     }
   if(strlen(tok_ptr = my_strtok(NULL,"\t"))!=0)
     {  
-      record.date_posted = gnc_iso8601_to_timespec_local(tok_ptr);
+      record.date_posted = gnc_iso8601_to_timespec_gmt(tok_ptr);
       record.date_posted_present=TRUE;
     }
   if(strlen(tok_ptr = my_strtok(NULL,"\t"))!=0)
@@ -245,7 +242,7 @@ static split_record interpret_split_record( char *record_line)
     }
   if(strlen(tok_ptr = my_strtok(NULL,"\t"))!=0)
     {  
-      record.date_reconciled = gnc_iso8601_to_timespec_local(tok_ptr);
+      record.date_reconciled = gnc_iso8601_to_timespec_gmt(tok_ptr);
       record.date_reconciled_present=TRUE;
     }
 
@@ -279,15 +276,11 @@ static void dump_split_record(split_record record)
     }
   if(record.trans_guid_present)
     {
-      string_ptr = guid_to_string (&(record.trans_guid));
-      DEBUG("Transaction GUID: %s", string_ptr);
-      g_free(string_ptr);
+      DEBUG("Transaction GUID: %s", guid_to_string (&(record.trans_guid)));
     }
   if(record.split_guid_present)
     {
-      string_ptr = guid_to_string (&(record.split_guid));
-      DEBUG("Split GUID: %s", string_ptr);
-      g_free(string_ptr);
+      DEBUG("Split GUID: %s", guid_to_string (&(record.split_guid)));
     }
   if(record.log_date_present)
     {
@@ -306,9 +299,7 @@ static void dump_split_record(split_record record)
     }
   if(record.acc_guid_present)
     {
-      string_ptr = guid_to_string (&(record.acc_guid));
-      DEBUG("Account GUID: %s", string_ptr);
-      g_free(string_ptr);
+      DEBUG("Account GUID: %s", guid_to_string (&(record.acc_guid)));
     }
   if(record.acc_name_present)
     {
@@ -495,6 +486,7 @@ static void  process_trans_record(  FILE *log_file)
 	  DEBUG("process_trans_record(): Record ended\n");
 	  if(trans!=NULL)/*If we played with a transaction, commit it here*/
 	    {
+	      xaccTransScrubCurrencyFromSplits(trans);
 	      xaccTransCommitEdit(trans);
 	    }
 	}
@@ -503,70 +495,94 @@ static void  process_trans_record(  FILE *log_file)
 
 void gnc_file_log_replay (void)
 {
-  const char *selected_filename;
+  char *selected_filename;
   char *default_dir;
   char read_buf[256];
   char *read_retval;
+  GtkFileFilter *filter;
   FILE *log_file;
-  char * expected_header = "mod	trans_guid	split_guid	time_now	date_entered	date_posted	acc_guid	acc_name	num	description	notes	memo	action	reconciled	amount	value	date_reconciled";
   char * record_start_str = "===== START";
+  /* NOTE: This string must match src/engine/TransLog.c (sans newline) */
+  char * expected_header_orig = "mod\ttrans_guid\tsplit_guid\ttime_now\t"
+  	"date_entered\tdate_posted\tacc_guid\tacc_name\tnum\tdescription\t"
+  	"notes\tmemo\taction\treconciled\tamount\tvalue\tdate_reconciled";
+  static char *expected_header = NULL;
 
-  gnc_should_log(MOD_IMPORT, GNC_LOG_DEBUG);
-  DEBUG("gnc_file_log_replay(): Begin...\n");
+  /* Use g_strdup_printf so we don't get accidental tab -> space conversion */
+  if (!expected_header)
+    expected_header = g_strdup_printf(expected_header_orig);
 
-  default_dir = gnc_lookup_string_option("__paths", "Log Files", NULL);
+  qof_log_set_level(GNC_MOD_IMPORT, QOF_LOG_DEBUG);
+  ENTER(" ");
+
+  default_dir = gnc_gconf_get_string(GCONF_SECTION, KEY_LAST_PATH, NULL);
   if (default_dir == NULL)
     gnc_init_default_directory(&default_dir);
+
+  filter = gtk_file_filter_new();
+  gtk_file_filter_set_name(filter, "*.log");
+  gtk_file_filter_add_pattern(filter, "*.[Ll][Oo][Gg]");
   selected_filename = gnc_file_dialog(_("Select a .log file to replay"),
-				      NULL,
-				      default_dir);
+				      g_list_prepend(NULL, filter),
+				      default_dir,
+				      GNC_FILE_DIALOG_OPEN);
 
   if(selected_filename!=NULL)
     {
       /* Remember the directory as the default. */
       gnc_extract_directory(&default_dir, selected_filename);
-      gnc_set_string_option("__paths", "Log Files", default_dir);
-      g_free(default_dir);
+      gnc_gconf_set_string(GCONF_SECTION, KEY_LAST_PATH, default_dir, NULL);
 
       /*strncpy(file,selected_filename, 255);*/
       DEBUG("Filename found: %s",selected_filename);
-
-      DEBUG("Opening selected file");
-      log_file = fopen(selected_filename, "r");
-      if(ferror(log_file)!=0)
-	{
+      if (xaccFileIsCurrentLog(selected_filename)) {
+	g_warning("Cannot open the current log file: %s", selected_filename);
+	gnc_error_dialog(NULL,
+			 /* Translators: %s is the file name. */
+			 _("Cannot open the current log file: %s"),
+			 selected_filename);
+      } else {
+	DEBUG("Opening selected file");
+	log_file = fopen(selected_filename, "r");
+	if(!log_file || ferror(log_file)!=0) {
+	  int err = errno;
 	  perror("File open failed");
-	}
-      else
-	{
-	  if((read_retval = fgets(read_buf,sizeof(read_buf),log_file)) == NULL)
-	    {
+	  gnc_error_dialog(NULL,
+			   /* Translation note:
+			    * First argument is the filename,
+			    * second argument is the error.
+			    */
+			   _("Failed to open log file: %s: %s"),
+			   selected_filename,
+			   strerror(err));
+	} else {
+	  if((read_retval = fgets(read_buf,sizeof(read_buf),log_file)) == NULL) {
 	      DEBUG("Read error or EOF");
-	    }
-	  else
-	    {
-	      if(strncmp(expected_header,read_buf,strlen(expected_header))!=0)
-		{
-		  PERR("File header not recognised:\n%s",read_buf);
-		  PERR("Expected:\n%s",expected_header);
-		}
-	      else
-		{
-		  do
-		    {
-		      read_retval = fgets(read_buf,sizeof(read_buf),log_file);
-		      /*DEBUG("Chunk read: %s",read_retval);*/
-		      if(strncmp(record_start_str,read_buf,strlen(record_start_str))==0)/* If a record started */
-			{
-			  process_trans_record(log_file);
-			}
-		    }while(feof(log_file)==0);
+	      gnc_info_dialog(NULL, "%s",
+			      _("The log file you selected was empty."));
+	  } else {
+	    if(strncmp(expected_header,read_buf,strlen(expected_header))!=0) {
+		PERR("File header not recognised:\n%s",read_buf);
+		PERR("Expected:\n%s",expected_header);
+		gnc_error_dialog(NULL, "%s",
+				 _("The log file you selected cannot be read.  "
+				   "The file header was not recognized."));
+	    } else {
+	      do {
+		read_retval = fgets(read_buf,sizeof(read_buf),log_file);
+		/*DEBUG("Chunk read: %s",read_retval);*/
+		if(strncmp(record_start_str,read_buf,strlen(record_start_str))==0) {/* If a record started */
+		  process_trans_record(log_file);
 		}
+	      }while(feof(log_file)==0);
 	    }
+	  }
 	  fclose(log_file);
 	}
+      }
+      g_free(selected_filename);
     }
-  
+  g_free(default_dir);
 }
 
 
