@@ -4,45 +4,44 @@
 ;;;  form. 
 ;;;
 ;;;  Bill Gribble <grib@billgribble.com> 20 Feb 2000 
-;;;  $Id: qif-dialog-utils.scm,v 1.3.2.1 2004/08/19 19:59:00 warlord Exp $
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (use-modules (ice-9 regex))
 
 (define (default-stock-acct brokerage security)
-  (string-append brokerage (gnc:account-separator-char) security))
+  (string-append brokerage (gnc:account-separator-string) security))
 
 (define (default-dividend-acct brokerage security)
-  (string-append (_ "Dividends") (gnc:account-separator-char) 
-                 brokerage (gnc:account-separator-char) 
+  (string-append (_ "Dividends") (gnc:account-separator-string) 
+                 brokerage (gnc:account-separator-string) 
                  security))
 
 (define (default-interest-acct brokerage security) 
-  (string-append (_ "Interest") (gnc:account-separator-char) 
+  (string-append (_ "Interest") (gnc:account-separator-string) 
                  brokerage
 		 (if (string=? security "")
 		  ""
-		  (string-append (gnc:account-separator-char)  
+		  (string-append (gnc:account-separator-string)  
 				  security))))
 
 (define (default-capital-return-acct brokerage security) 
-  (string-append (_ "Cap Return") (gnc:account-separator-char) 
-                 brokerage (gnc:account-separator-char)  
+  (string-append (_ "Cap Return") (gnc:account-separator-string) 
+                 brokerage (gnc:account-separator-string)  
                  security))
 
 (define (default-cglong-acct brokerage security)
-  (string-append (_ "Cap. gain (long)") (gnc:account-separator-char) 
-                 brokerage (gnc:account-separator-char) 
+  (string-append (_ "Cap. gain (long)") (gnc:account-separator-string) 
+                 brokerage (gnc:account-separator-string) 
                  security))
 
 (define (default-cgmid-acct brokerage security)
-  (string-append (_ "Cap. gain (mid)") (gnc:account-separator-char) 
-                 brokerage (gnc:account-separator-char) 
+  (string-append (_ "Cap. gain (mid)") (gnc:account-separator-string) 
+                 brokerage (gnc:account-separator-string) 
                  security))
 
 (define (default-cgshort-acct brokerage security)
-  (string-append (_ "Cap. gain (short)") (gnc:account-separator-char) 
-                 brokerage (gnc:account-separator-char) 
+  (string-append (_ "Cap. gain (short)") (gnc:account-separator-string) 
+                 brokerage (gnc:account-separator-string) 
                  security))
 
 (define (default-equity-holding security) (_ "Retained Earnings"))
@@ -50,11 +49,11 @@
 (define (default-equity-account) (_ "Retained Earnings"))  
 
 (define (default-commission-acct brokerage) 
-  (string-append (_ "Commissions") (gnc:account-separator-char) 
+  (string-append (_ "Commissions") (gnc:account-separator-string) 
                  brokerage))
 
 (define (default-margin-interest-acct brokerage) 
-  (string-append (_ "Margin Interest") (gnc:account-separator-char) 
+  (string-append (_ "Margin Interest") (gnc:account-separator-string) 
                  brokerage))
 
 (define (default-unspec-acct)
@@ -568,7 +567,7 @@
   (if (not qif-import:account-name-regexp)
       (let* ((rstr ":([^:]+)$|^([^:]+)$")
              (newstr (regexp-substitute/global 
-                      #f ":" rstr 'pre (gnc:account-separator-char) 'post)))
+                      #f ":" rstr 'pre (gnc:account-separator-string) 'post)))
         
         (set! qif-import:account-name-regexp (make-regexp newstr))))
   
@@ -605,12 +604,12 @@
                   (memv GNC-MUTUAL-TYPE 
                         (qif-map-entry:allowed-types map-entry)))
               (not (hash-ref stock-hash stock-name)))
-             (let* ((separator (string-ref (gnc:account-separator-char) 0))
+             (let* ((separator (string-ref (gnc:account-separator-string) 0))
                     (existing-gnc-acct 
                      (gnc:get-account-from-full-name 
                       (gnc:get-current-group)
-                      (qif-map-entry:gnc-name map-entry)
-                      separator))
+                      (qif-map-entry:gnc-name map-entry)))
+		    (book (gnc:group-get-book (gnc:get-current-group)))
                     (existing-type 
                      (gnc:account-get-type existing-gnc-acct)))
                (if (and existing-gnc-acct 
@@ -630,7 +629,8 @@
                      (set! names (cons stock-name names))
                      (hash-set! 
                       stock-hash stock-name 
-                      (gnc:commodity-create stock-name
+                      (gnc:commodity-create book
+					    stock-name
                                             GNC_COMMODITY_NS_NYSE
                                             ticker-symbol
                                             ""
@@ -685,7 +685,7 @@
 
   (let ((accts '())
         (acct-tree '())
-        (separator (string-ref (gnc:account-separator-char) 0)))
+        (separator (string-ref (gnc:account-separator-string) 0)))
     ;; get the new accounts from the account map
     (for-each 
      (lambda (acctmap)
