@@ -3,7 +3,6 @@
 ;;;  read a QIF file into a <qif-file> object
 ;;;
 ;;;  Bill Gribble <grib@billgribble.com> 20 Feb 2000 
-;;;  $Id: qif-file.scm,v 1.5.2.5 2003/05/17 18:39:16 warlord Exp $
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -12,6 +11,8 @@
 ;;  just store the fields "raw".
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(use-modules (g-wrapped gw-core-utils))
+
 (cond
  ((or (string=? "1.3.4" (version))
       (string=? "1.4" (substring (version) 0 3))) #f)
@@ -24,7 +25,7 @@
   (let ((match (regexp-exec qif-bad-numeric-rexp input)))
     (if match #f #t)))
 
-(define (qif-file:read-file self path ticker-map)
+(define (qif-file:read-file self path ticker-map window)
   (false-if-exception
    (let* ((qstate-type #f)
           (current-xtn #f)
@@ -52,11 +53,10 @@
 
      (if (> file-size 10000)
          (begin
-           (set! progress-dialog (gnc:progress-dialog-new #f #f))
+           (set! progress-dialog (gnc:progress-dialog-new window #f))
            (gnc:progress-dialog-set-title progress-dialog (_ "Progress"))
            (gnc:progress-dialog-set-heading progress-dialog
-                                            (_ "Loading QIF file..."))
-           (gnc:progress-dialog-set-limits progress-dialog 0.0 100.0)))
+                                            (_ "Loading QIF file..."))))
 
      (with-input-from-file path
        (lambda ()
@@ -73,12 +73,13 @@
 
                  ;; pick the 1-char tag off from the remainder of the line 
                  (set! tag (string-ref line 0))
-                 (set! value (make-shared-substring line 1))
+                 (set! value (substring line 1))
+		 (gnc:utf8-strip-invalid value)
                  
                  ;; now do something with the line 
                  (if
                   (eq? tag #\!)
-                  (begin 
+                  (let ((old-qstate qstate-type))
                     (set! qstate-type (qif-parse:parse-bang-field value))
                     (case qstate-type 
                       ((type:bank type:cash type:ccard type:invst type:port 
@@ -100,7 +101,17 @@
                       ((option:autoswitch)
                        (set! ignore-accounts #t))
                       ((clear:autoswitch)
-                       (set! ignore-accounts #f))))
+                       (set! ignore-accounts #f))
+                      (else
+		       ;; Ignore any other "option:" identifiers and
+		       ;; just return to the previously known !type
+                       (if (string-match "^option:"
+                                         (symbol->string qstate-type))
+                           (begin
+                             (display "qif-file:read-file ignoring ")
+                             (write qstate-type)
+                             (newline)
+                             (set! qstate-type old-qstate))))))
                   
 ;;;                        (#t 
 ;;;                         (display "qif-file:read-file can't handle ")
@@ -378,8 +389,7 @@
 		 (if progress-dialog 
 		     (begin 
 		       (gnc:progress-dialog-set-value 
-			progress-dialog
-			(* 100 (/ bytes-read file-size)))
+			progress-dialog (/ bytes-read file-size))
 		       (gnc:progress-dialog-update progress-dialog)))
                  
                  ;; this is if we read a normal (non-null, non-eof) line...
