@@ -1,7 +1,7 @@
 (define-module (g-wrapped gw-register-core-spec))
 
 (debug-set! maxdepth 100000)
-(debug-set! stack    2000000)
+(debug-set! stack    200000)
 
 (use-modules (g-wrap))
 
@@ -18,9 +18,9 @@
   (gw:wrapset-add-cs-declarations!
    ws
    (lambda (wrapset client-wrapset) 
-     (if (eq? wrapset client-wrapset)
-         '()
-         "#include <basiccell.h>\n")))
+     (list
+      "#include <config.h>\n"
+      "#include <basiccell.h>\n" )))
   
   (gw:wrap-as-wct ws '<gnc:basic-cell> "BasicCell*" "const BasicCell*")
 
