@@ -15,8 +15,8 @@
  * along with this program; if not, contact:                        *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
- * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
 
@@ -42,8 +42,7 @@
 
 #include "table-allgui.h"
 #include "cellblock.h"
-#include "dialog-utils.h"
-#include "gnc-engine-util.h"
+#include "gnc-engine.h"
 
 
 /** Static Globals *****************************************************/
@@ -51,14 +50,13 @@
 static TableGUIHandlers default_gui_handlers;
 
 /* This static indicates the debugging module that this .o belongs to. */
-static short module = MOD_REGISTER;
+static QofLogModule log_module = GNC_MOD_REGISTER;
 
 
 /** Prototypes *********************************************************/
 static void gnc_table_init (Table * table);
 static void gnc_table_free_data (Table * table);
 static void gnc_virtual_cell_construct (gpointer vcell, gpointer user_data);
-static void gnc_virtual_location_init (VirtualLocation *vloc);
 static void gnc_virtual_cell_destroy (gpointer vcell, gpointer user_data);
 static void gnc_table_resize (Table * table, int virt_rows, int virt_cols);
 
@@ -390,6 +388,30 @@ gnc_table_get_bg_color (Table *table, VirtualLocation virt_loc,
                            table->model->handler_user_data);
 }
 
+guint32
+gnc_table_get_gtkrc_bg_color (Table *table, VirtualLocation virt_loc,
+			      gboolean *hatching)
+{
+  TableGetBGColorHandler bg_color_handler;
+  const char *cell_name;
+
+  if (hatching)
+    *hatching = FALSE;
+
+  if (!table || !table->model)
+    return 0xffffff; /* white */
+
+  cell_name = gnc_table_get_cell_name (table, virt_loc);
+
+  bg_color_handler = gnc_table_model_get_bg_color_handler (table->model,
+                                                           "gtkrc");
+  if (!bg_color_handler)
+    return 0xffffff;
+
+  return bg_color_handler (virt_loc, hatching,
+                           table->model->handler_user_data);
+}
+
 void
 gnc_table_get_borders (Table *table, VirtualLocation virt_loc,
                        PhysicalCellBorders *borders)
@@ -542,7 +564,7 @@ gnc_table_save_cells (Table *table, gpointer save_data)
   if (gnc_table_model_read_only (table->model))
     return;
 
-  gnc_table_leave_update (table, table->current_cursor_loc);
+  // gnc_table_leave_update (table, table->current_cursor_loc);
 
   save_handler = gnc_table_model_get_pre_save_handler (table->model);
   if (save_handler)
@@ -597,7 +619,7 @@ gnc_table_free_data (Table * table)
   g_table_resize (table->virt_cells, 0, 0);
 }
 
-static void
+void
 gnc_virtual_location_init (VirtualLocation *vloc)
 {
   if (vloc == NULL)
@@ -1184,9 +1206,9 @@ gnc_table_confirm_change (Table *table, VirtualLocation virt_loc)
 const char *
 gnc_table_modify_update (Table *table,
                          VirtualLocation virt_loc,
-                         const GdkWChar *change,
+                         const char *change,
                          int change_len,
-                         const GdkWChar *newval,
+                         const char *newval,
                          int newval_len,
                          int *cursor_position,
                          int *start_selection,
@@ -1242,9 +1264,7 @@ gnc_table_modify_update (Table *table,
         cursor_position, start_selection, end_selection);
   else
   {
-    char *newval_mb = gnc_wcstombs (newval);
-    gnc_basic_cell_set_value (cell, newval_mb);
-    g_free (newval_mb);
+    gnc_basic_cell_set_value (cell, newval);
   }
 
   if (safe_strcmp (old_value, cell->value) != 0)
