@@ -7,7 +7,7 @@
 
 #include "config.h"
 #include <stdio.h>
-#include <guile/gh.h>
+#include <libguile.h>
 #include <glib.h>
 #include <locale.h>
 #include <string.h>
@@ -56,13 +56,13 @@ libgncmod_locale_reports_us_LTX_gnc_module_init(int refcount) {
 #else
   gboolean is_de_DE = FALSE;
 #endif /* LOCALE_SPECIFIC_TAX */
-  char *tax_module = is_de_DE ? 
+  const char *tax_module = is_de_DE ? 
     "gnucash/tax/de_DE" : 
     "gnucash/tax/us";
-  char *report_taxtxf = is_de_DE ? 
+  const char *report_taxtxf = is_de_DE ? 
     "(use-modules (gnucash report taxtxf-de_DE))" :
     "(use-modules (gnucash report taxtxf))";
-  char *report_locale = is_de_DE ?
+  const char *report_locale = is_de_DE ?
     "(use-modules (gnucash report locale-specific de_DE))" :
     "(use-modules (gnucash report locale-specific us))";
 
@@ -78,14 +78,14 @@ libgncmod_locale_reports_us_LTX_gnc_module_init(int refcount) {
   }
 
   /* load the report generation scheme code */
-  if(gh_eval_str(report_taxtxf) 
+  if(scm_c_eval_string(report_taxtxf) 
      == SCM_BOOL_F) {
     printf("failed to load %s\n", report_taxtxf);
     return FALSE;
   }
 
   /* Load the module scheme code */
-  if(gh_eval_str(report_locale) 
+  if(scm_c_eval_string(report_locale) 
      == SCM_BOOL_F) {
     return FALSE;
   }
